package cd.casic.ci.log.service;

import cd.casic.ci.log.dal.pojo.*;
import cd.casic.framework.commons.pojo.CommonResult;
import cd.casic.ci.log.dal.pojo.enums.LogStatusEnum;
import cd.casic.ci.log.dal.pojo.enums.LogType;
import cd.casic.ci.log.jmx.LogStorageBean;
import jakarta.annotation.Resource;
import org.springframework.http.ResponseEntity;

/**
 * @author by mianbin
 * @Classname BuildLogQueryService
 * @Description TODO
 * @Date 2025/3/20 14:59
 */
public class BuildLogQueryService {

    @Resource
    private LogService logService;
    @Resource
    private LogStatusService logStatusService;
    @Resource
    private IndexService indexService;
    @Resource
    private LogStorageBean logStorageBean;

    public CommonResult<QueryLogs> getInitLogs(String userId, String projectId, String pipelineId,
                                               String buildId, boolean debug, LogType logType, String tag, String jobId, int executeCount, String subTag) {
        // todo 鉴权代码
        // validateAuth(userId, projectId, pipelineId, buildId, AuthPermission.VIEW);
        long startEpoch = System.currentTimeMillis();
        boolean success = false;
        try {
            QueryLogs result = logService.queryInitLogs(buildId, debug, logType, tag, subTag, jobId, executeCount);
            // 设置查出来使用的时间
            result.setTimeUsed(System.currentTimeMillis() - startEpoch);
            // 判断当前查出来的日志的状态
            success = logStatusSuccess(result.getStatus());
            QueryLogs queryLogs = result;
            return CommonResult.success(queryLogs);
        } finally {
            logStorageBean.query(System.currentTimeMillis() - startEpoch, success);
        }
    }

    public CommonResult<PageQueryLogs> getInitLogsPage(String userId, String projectId, String pipelineId,
                                                       String buildId, boolean debug, LogType logType, String tag, String jobId, int executeCount,
                                                       int page, int pageSize, String subTag) {
        // todo 鉴权代码
        // validateAuth(userId, projectId, pipelineId, buildId, AuthPermission.VIEW);
        long startEpoch = System.currentTimeMillis();
        boolean success = false;
        try {
            PageQueryLogs result = logService.queryInitLogsPage(buildId, debug, logType, tag, subTag, jobId, executeCount,page,pageSize);
            // 设置查出来使用的时间
            result.setTimeUsed(System.currentTimeMillis() - startEpoch);
            // 判断当前查出来的日志的状态
            success = logStatusSuccess(result.getStatus());
            return CommonResult.success(result);
        } finally {
            logStorageBean.query(System.currentTimeMillis() - startEpoch, success);
        }
    }

    public CommonResult<QueryLogs> getMoreLogs(String userId, String projectId, String pipelineId, String buildId, boolean debug,
                                               LogType logType, int num, boolean fromStart, long start, long end, String tag, String jobId, int executeCount,String subTag) {
        // todo 鉴权代码
//        validateAuth(userId, projectId, pipelineId, buildId, AuthPermission.VIEW)
        long startEpoch = System.currentTimeMillis();
        boolean success = false;
        try {
            QueryLogs result = logService.queryLogsBetweenLines(buildId,num,fromStart,start,end, debug, logType, tag, subTag, jobId, executeCount);
            // 设置查出来使用的时间
            result.setTimeUsed(System.currentTimeMillis() - startEpoch);
            // 判断当前查出来的日志的状态
            success = logStatusSuccess(result.getStatus());
            return CommonResult.success(result);
        } finally {
            logStorageBean.query(System.currentTimeMillis() - startEpoch, success);
        }
    }

    public CommonResult<QueryLogs> getAfterLogs(String userId, String projectId, String pipelineId, String buildId,
                                                long start, boolean debug, LogType logType, String tag, String jobId, int executeCount,String subTag) {
        //        validateAuth(userId, projectId, pipelineId, buildId, AuthPermission.VIEW)
        long startEpoch = System.currentTimeMillis();
        boolean success = false;
        try {
            QueryLogs result = logService.queryLogsAfterLine(buildId,start,debug,logType,tag, subTag, jobId, executeCount);
            // 设置查出来使用的时间
            result.setTimeUsed(System.currentTimeMillis() - startEpoch);
            // 判断当前查出来的日志的状态
            success = logStatusSuccess(result.getStatus());
            return CommonResult.success(result);
        } finally {
            logStorageBean.query(System.currentTimeMillis() - startEpoch, success);
        }
    }

    public CommonResult<QueryLogs> getBeforeLogs(String userId, String projectId, String pipelineId, String buildId,
                                                 long end, boolean debug, LogType logType, int size, String tag, String jobId, int executeCount, String subTag) {
        //        validateAuth(userId, projectId, pipelineId, buildId, AuthPermission.VIEW)
        long startEpoch = System.currentTimeMillis();
        boolean success = false;
        try {
            QueryLogs result = logService.queryLogsBeforeLine(buildId,end,size,debug,logType,tag, subTag, jobId, executeCount);
            // 设置查出来使用的时间
            result.setTimeUsed(System.currentTimeMillis() - startEpoch);
            // 判断当前查出来的日志的状态
            success = logStatusSuccess(result.getStatus());
            return CommonResult.success(result);
        } finally {
            logStorageBean.query(System.currentTimeMillis() - startEpoch, success);
        }
    }

    public CommonResult<EndPageQueryLogs> getEndLogsPage(String userId, String projectId, String pipelineId, String buildId,
                                                         int size, boolean debug, LogType logType, String tag, String jobId, int executeCount, String subTag) {
        //        validateAuth(userId, projectId, pipelineId, buildId, AuthPermission.VIEW)
        long startEpoch = System.currentTimeMillis();
        boolean success = false;
        try {
            EndPageQueryLogs result = logService.getEndLogsPage(pipelineId,buildId,debug,logType,tag, subTag, jobId, executeCount,size);
            // 设置查出来使用的时间
            result.setTimeUsed(System.currentTimeMillis() - startEpoch);
            // 判断当前查出来的日志的状态
            success = logStatusSuccess(result.getStatus());
            return CommonResult.success(result);
        } finally {
            logStorageBean.query(System.currentTimeMillis() - startEpoch, success);
        }
    }

    public CommonResult<QueryLogs> getBottomLogs(String userId, String projectId, String pipelineId, String buildId,
                                                 int size, boolean debug, LogType logType, String tag, String jobId, int executeCount, String subTag) {
        //        validateAuth(userId, projectId, pipelineId, buildId, AuthPermission.VIEW)
        long startEpoch = System.currentTimeMillis();
        boolean success = false;
        try {
            QueryLogs result = logService.getBottomLogs(pipelineId,buildId,debug,logType,tag, subTag, jobId, executeCount,size);
            // 设置查出来使用的时间
            result.setTimeUsed(System.currentTimeMillis() - startEpoch);
            // 判断当前查出来的日志的状态
            success = logStatusSuccess(result.getStatus());
            return CommonResult.success(result);
        } finally {
            logStorageBean.query(System.currentTimeMillis() - startEpoch, success);
        }
    }

    public CommonResult<QueryLogStatus> getLogMode(String userId, String projectId, String pipelineId, String buildId, String tag, int executeCount) {
        // 鉴权
        // validateAuth(userId, projectId, pipelineId, buildId, AuthPermission.VIEW)
        // 这里的 executeCount 默认为1
        return CommonResult.success(logStatusService.getStorageMode(buildId,tag,executeCount));
    }

    // 获取当前构建的最大行号
    public CommonResult<QueryLogLineNum> getLastLineNum(String userId, String projectId, String pipelineId, String buildId) {
        // validateAuth(userId, projectId, pipelineId, buildId, AuthPermission.VIEW)
        long lastLineNum = indexService.getLastLineNum(buildId);
        boolean finished = logStatusService.isFinish(buildId, null, null, null, 1);
        QueryLogLineNum res = new QueryLogLineNum(buildId, finished, lastLineNum);
        return CommonResult.success(res);
    }

    private boolean logStatusSuccess(int logStatus) {
        return LogStatusEnum.parse(logStatus) == LogStatusEnum.EMPTY ||
                LogStatusEnum.parse(logStatus) == LogStatusEnum.SUCCEED;
    }

    public ResponseEntity downloadLogs(String userId, String projectId, String pipelineId, String buildId,
                                       String tag, String jobId, int executeCount, String finaName, String subTag) {
        return null;
    }

}
