package cd.casic.ci.process.api.engine.common;

import cd.casic.ci.process.api.process.utils.PipelineVarUtil;

import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * @author by mianbin
 * @Classname Timeout
 * @Description TODO
 * @Date 2025/3/31 16:13
 */
public class Timeout {
    public static final long DEFAULT_TIMEOUT_MIN = 900L;
    public static final long DEFAULT_PREPARE_MINUTES = 10L;
    public static final long DEFAULT_STAGE_TIMEOUT_HOURS = 24L;
    private static final long MAX_STAGE_REVIEW_DAYS = 30L;
    public static final long MAX_JOB_RUN_DAYS = 7L;

    public static final long MAX_HOURS = TimeUnit.DAYS.toHours(MAX_STAGE_REVIEW_DAYS);
    public static final long STAGE_MAX_MILLS = TimeUnit.HOURS.toMillis(MAX_HOURS) + 1;
    public static final int MAX_MINUTES = (int) TimeUnit.DAYS.toMinutes(MAX_JOB_RUN_DAYS);
    public static final long CONTAINER_MAX_MILLS = TimeUnit.MINUTES.toMillis(MAX_MINUTES) + 1;

    private static TimeoutObj transTimeoutObj(String timeoutStr) {
        boolean change = false;
        long minute;
        try {
            if (timeoutStr != null && !timeoutStr.isEmpty()) {
                minute = Integer.parseInt(timeoutStr);
            } else {
                change = true;
                minute = DEFAULT_TIMEOUT_MIN;
            }
        } catch (Exception badConfig) {
            change = true;
            minute = DEFAULT_TIMEOUT_MIN;
        }
        if (minute <= 0 || minute > MAX_MINUTES) {
            change = true;
            minute = MAX_MINUTES;
        }
        return new TimeoutObj(
                timeoutStr,
                minute,
                transMinuteTimeoutToMills(minute),
                change
        );
    }

    public static long transMinuteTimeoutToSec(Long timeoutMinutes) {
        long minute = timeoutMinutes != null ? timeoutMinutes : DEFAULT_TIMEOUT_MIN;
        if (minute <= 0 || minute > MAX_MINUTES) {
            minute = MAX_MINUTES;
        }
        return TimeUnit.MINUTES.toSeconds(minute) + 1;
    }

    public static long transMinuteTimeoutToMills(Long timeoutMinutes) {
        long minute = timeoutMinutes != null ? timeoutMinutes : DEFAULT_TIMEOUT_MIN;
        if (minute <= 0 || minute > MAX_MINUTES) {
            minute = MAX_MINUTES;
        }
        return TimeUnit.MINUTES.toMillis(minute) + 1;
    }

    public static TimeoutObj decTimeout(String timeoutVar, Map<String, String> contextMap) {
        TimeoutObj obj;
        String timeoutStr = timeoutVar != null ? timeoutVar.trim() : null;
        if (PipelineVarUtil.isVar(timeoutStr)) {
//            String tTimeout = EnvReplacementParser.parse(timeoutStr, contextMap);
            String tTimeout = "";
            obj = transTimeoutObj(tTimeout);
            if (!tTimeout.equals(timeoutStr)) {
                obj.replaceByVar = true;
            }
        } else {
            obj = transTimeoutObj(timeoutStr);
        }
        return obj;
    }

    public static class TimeoutObj {
        public String beforeChangeStr;
        public long minutes;
        public long millis;
        public boolean change;
        public boolean replaceByVar;

        public TimeoutObj(String beforeChangeStr, long minutes, long millis, boolean change) {
            this.beforeChangeStr = beforeChangeStr;
            this.minutes = minutes;
            this.millis = millis;
            this.change = change;
            this.replaceByVar = false;
        }
    }
}
