package cd.casic.ci.process.process.callback.listener;


import cd.casic.ci.process.process.engine.control.CallBackControl;
import cd.casic.ci.project.dal.pojo.ProjectCreateInfo;
import cd.casic.ci.project.dal.pojo.ProjectVO;
import cd.casic.ci.project.pojo.ProjectUpdateInfo;
import cd.casic.ci.project.pojo.mq.ProjectBroadCastEvent;
import cd.casic.ci.project.pojo.mq.ProjectCreateBroadCastEvent;
import cd.casic.ci.project.pojo.mq.ProjectEnableStatusBroadCastEvent;
import cd.casic.ci.project.pojo.mq.ProjectUpdateBroadCastEvent;
import cd.casic.ci.project.service.ProjectService;
import cd.casic.framework.mq.redis.core.stream.AbstractRedisStreamMessageListener;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

@Service
@Slf4j
public class ProjectCallbackEventListener extends AbstractRedisStreamMessageListener<ProjectBroadCastEvent> {
    @Resource
    private CallBackControl callBackControl;
    private ProjectService projectService;
    @Override
    public void onMessage(ProjectBroadCastEvent event) {
        log.info("Receive ProjectEvent from MQ [$event]");
        try {
            if (event instanceof ProjectUpdateBroadCastEvent) {
                onReceiveProjectUpdate((ProjectUpdateBroadCastEvent)event);
            } else if (event instanceof ProjectEnableStatusBroadCastEvent) {
                onReceiveProjectEnable((ProjectEnableStatusBroadCastEvent)event);
            } else if (event instanceof ProjectCreateBroadCastEvent) {
                onReceiveProjectCreate((ProjectCreateBroadCastEvent)event);
            }
        } catch (Exception e) {
            log.error("BKSystemMonitor| project callback listener execute error", e);
        }
    }
    /**
     *  处理创建项目事件
     *  @param event ProjectCreateBroadCastEvent
     */
    private void onReceiveProjectCreate(ProjectCreateBroadCastEvent event){
        ProjectCreateInfo projectInfo = event.getProjectInfo();
        callBackControl.projectCreate(
                projectInfo.getEnglishName(),
                projectInfo.getProjectName(),
                event.getUserId());
    }
    /**
     *  处理更新项目事件
     *  @param event ProjectUpdateBroadCastEvent
     */
    private void onReceiveProjectUpdate(ProjectUpdateBroadCastEvent event){
        ProjectUpdateInfo projectInfo = event.getProjectInfo();
        callBackControl.projectUpdate(
                projectInfo.getEnglishName(),
                projectInfo.getProjectName(),
                event.getUserId()
        );
    }
    /**
     *  处理项目禁用事件
     *  @param event ProjectEnableStatusBroadCastEvent
     */
    private void onReceiveProjectEnable(ProjectEnableStatusBroadCastEvent event){
        ProjectVO project = getProject(event.getProjectId());
        if (project!=null) {
            if (event.getEnable()) {
                callBackControl.projectEnable(event.getProjectId(),project.getProjectName(),event.getUserId());
            } else {
                callBackControl.projectDisable(event.getProjectId(),project.getProjectName(),event.getUserId());
            }
        }
    }


    private ProjectVO getProject(String projectEnglishName){
        if (StringUtils.isEmpty(projectEnglishName)) {
            return null;
        }
        try {
            return projectService.getByEnglishName(projectEnglishName);
        } catch (Exception e) {
            log.warn(
                    "fail to get project info|projectEnglishName[$projectEnglishName]",
                    e
            );
            return null;
        }
    }
}
