/*
 * Tencent is pleased to support the open source community by making BK-CI 蓝鲸持续集成平台 available.
 *
 * Copyright (C) 2019 THL A29 Limited, a Tencent company.  All rights reserved.
 *
 * BK-CI 蓝鲸持续集成平台 is licensed under the MIT license.
 *
 * A copy of the MIT License is included in this file.
 *
 *
 * Terms of the MIT License:
 * ---------------------------------------------------
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
 * documentation files (the "Software"), to deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of
 * the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
 * LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package cd.casic.ci.process.process.dal.atom;


import cd.casic.ci.process.api.process.pojo.PipelineAtomReplaceHistory;
import cd.casic.ci.process.process.dataObject.TPipelineAtomReplaceHistoryRecord;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 流水线原子替换历史 Mapper 接口
 */
@Mapper
@Repository
public interface PipelineAtomReplaceHistoryDao {

    /**
     * 创建原子替换历史
     *
     * @param pipelineAtomReplaceHistory 原子替换历史信息
     */
    void createAtomReplaceHistory(
        @Param("pipelineAtomReplaceHistory") PipelineAtomReplaceHistory pipelineAtomReplaceHistory
    );

    /**
     * 获取原子替换历史列表
     *
     * @param baseId 基础ID
     * @param itemId 项ID
     * @param projectId 项目ID
     * @param busType 业务类型
     * @param statusList 状态列表
     * @param descFlag 是否降序
     * @param page 页码
     * @param pageSize 每页大小
     * @return 原子替换历史记录列表
     */
    List<TPipelineAtomReplaceHistoryRecord> getAtomReplaceHistoryList(
        @Param("baseId") String baseId,
        @Param("itemId") String itemId,
        @Param("projectId") String projectId,
        @Param("busType") String busType,
        @Param("statusList") List<String> statusList,
        @Param("descFlag") Boolean descFlag,
        @Param("page") Integer page,
        @Param("pageSize") Integer pageSize
    );

    /**
     * 更新原子替换历史
     *
     * @param id ID
     * @param status 状态
     * @param log 日志
     * @param userId 用户ID
     */
    void updateAtomReplaceHistory(
        @Param("id") String id,
        @Param("status") String status,
        @Param("log") String log,
        @Param("userId") String userId
    );
} 