/*
 * Tencent is pleased to support the open source community by making BK-CI 蓝鲸持续集成平台 available.
 *
 * Copyright (C) 2019 THL A29 Limited, a Tencent company.  All rights reserved.
 *
 * BK-CI 蓝鲸持续集成平台 is licensed under the MIT license.
 *
 * A copy of the MIT License is included in this file.
 *
 *
 * Terms of the MIT License:
 * ---------------------------------------------------
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
 * documentation files (the "Software"), to deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of
 * the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
 * LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package cd.casic.ci.process.process.dal.auth;

import cd.casic.ci.process.process.dataObject.TPipelineRemoteAuthRecord;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 流水线远程认证 Mapper 接口
 */
@Repository
public interface PipelineRemoteAuthDao {

    /**
     * 创建远程认证记录
     *
     * @param projectId 项目ID
     * @param pipelineId 流水线ID
     * @param authId 认证ID
     * @param authType 认证类型
     * @param authContent 认证内容
     * @param userId 用户ID
     * @return 远程认证记录ID
     */
    long create(
        @Param("projectId") String projectId,
        @Param("pipelineId") String pipelineId,
        @Param("authId") String authId,
        @Param("authType") String authType,
        @Param("authContent") String authContent,
        @Param("userId") String userId
    );

    /**
     * 更新远程认证记录
     *
     * @param projectId 项目ID
     * @param pipelineId 流水线ID
     * @param authId 认证ID
     * @param authType 认证类型
     * @param authContent 认证内容
     * @param userId 用户ID
     * @return 影响的行数
     */
    int update(
        @Param("projectId") String projectId,
        @Param("pipelineId") String pipelineId,
        @Param("authId") String authId,
        @Param("authType") String authType,
        @Param("authContent") String authContent,
        @Param("userId") String userId
    );

    /**
     * 删除远程认证记录
     *
     * @param projectId 项目ID
     * @param pipelineId 流水线ID
     * @param authId 认证ID
     * @return 影响的行数
     */
    int delete(
        @Param("projectId") String projectId,
        @Param("pipelineId") String pipelineId,
        @Param("authId") String authId
    );

    /**
     * 获取远程认证记录列表
     *
     * @param projectId 项目ID
     * @param pipelineId 流水线ID
     * @return 远程认证记录列表
     */
    List<TPipelineRemoteAuthRecord> list(
        @Param("projectId") String projectId,
        @Param("pipelineId") String pipelineId
    );

    /**
     * 获取远程认证记录
     *
     * @param projectId 项目ID
     * @param pipelineId 流水线ID
     * @param authId 认证ID
     * @return 远程认证记录
     */
    TPipelineRemoteAuthRecord get(
        @Param("projectId") String projectId,
        @Param("pipelineId") String pipelineId,
        @Param("authId") String authId
    );
} 