/*
 * Tencent is pleased to support the open source community by making BK-CI 蓝鲸持续集成平台 available.
 *
 * Copyright (C) 2019 THL A29 Limited, a Tencent company.  All rights reserved.
 *
 * BK-CI 蓝鲸持续集成平台 is licensed under the MIT license.
 *
 * A copy of the MIT License is included in this file.
 *
 *
 * Terms of the MIT License:
 * ---------------------------------------------------
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
 * documentation files (the "Software"), to deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of
 * the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
 * LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package cd.casic.ci.process.process.dal.callback;

import cd.casic.ci.process.process.dataObject.TProjectPipelineCallbackRecord;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.time.LocalDateTime;
import java.util.List;

/**
 * 项目流水线回调 Mapper 接口
 */
@Repository
public interface ProjectPipelineCallbackDao {

    /**
     * 可直接更新或插入
     */
    int save(
            @Param("projectId") String projectId,
            @Param("events") String events,
            @Param("userId") String userId,
            @Param("callbackUrl") String callbackUrl,
            @Param("secretToken") String secretToken,
            @Param("id") Long id,
            @Param("secretParam") String secretParam
    );


    List<TProjectPipelineCallbackRecord> listProjectCallback(
            @Param("projectId")String projectId,
            @Param("events")String events,
            @Param("enable")Boolean enable
    );

    List<TProjectPipelineCallbackRecord> listByPage(
            @Param("projectId")String projectId,
            @Param("offset")Integer offset,
            @Param("limit")Integer limit
    );

    Long countByPage(String projectId);

    TProjectPipelineCallbackRecord get(
            @Param("projectId") String projectId,
            @Param("id") Long id
    );

    int deleteById(
            @Param("projectId") String projectId,
            @Param("id") Long id
    );

    int deleteByProjectId(
            @Param("projectId") String projectId
    );

    int disable(
            @Param("projectId") String projectId,
            @Param("id") Long id
    );

    int enable(
           @Param("projectId") String projectId,
           @Param("id") Long id
    );

    List<TProjectPipelineCallbackRecord> getDisableCallbackList(
            @Param("projectId") String projectId,
            @Param("url") String url,
            @Param("offset") Integer offset,
            @Param("limit") Integer limit
    );

    int enableByIds(
            @Param("projectId") String projectId,
            @Param("ids") List<Integer>ids
    );

    int updateFailureTime(
           @Param("projectId") String projectId,
           @Param("id") Long id,
           @Param("failureTime") LocalDateTime failureTime
    );
} 