package cd.casic.ci.process.process.dal.label;


import cd.casic.ci.process.process.dataObject.TPipelineGroupRecord;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.util.List;
import java.util.Set;

/**
 * 流水线分组 Mapper 接口
 */
@Mapper
@Repository
public interface PipelineGroupDao {

    /**
     * 创建流水线分组
     *
     * @param projectId 项目ID
     * @param name 分组名称
     * @param userId 用户ID
     * @param id 主键ID
     * @return 分组ID
     */
    Long createPipelineGroup(
        @Param("projectId") String projectId,
        @Param("name") String name,
        @Param("userId") String userId,
        @Param("id") Long id
    );

    /**
     * 更新流水线分组
     *
     * @param projectId 项目ID
     * @param groupId 分组ID
     * @param name 分组名称
     * @param userId 用户ID
     * @return 是否更新成功
     */
    boolean update(
        @Param("projectId") String projectId,
        @Param("groupId") Long groupId,
        @Param("name") String name,
        @Param("userId") String userId
    );

    /**
     * 删除流水线分组
     *
     * @param projectId 项目ID
     * @param groupId 分组ID
     * @param userId 用户ID
     * @return 是否删除成功
     */
    boolean deletePipelineGroup(
        @Param("projectId") String projectId,
        @Param("groupId") Long groupId,
        @Param("userId") String userId
    );

    /**
     * 获取项目下的所有分组
     *
     * @param projectId 项目ID
     * @return 分组记录列表
     */
    List<TPipelineGroupRecord> list(
        @Param("projectId") String projectId
    );

    /**
     * 统计项目下的分组数量
     *
     * @param projectId 项目ID
     * @return 分组数量
     */
    long count(
        @Param("projectId") String projectId
    );

    /**
     * 统计项目下指定名称的分组数量
     *
     * @param projectId 项目ID
     * @param name 分组名称
     * @return 分组数量
     */
    long countByName(
        @Param("projectId") String projectId,
        @Param("name") String name
    );

    /**
     * 根据ID获取分组
     *
     * @param id 分组ID
     * @return 分组记录
     */
    TPipelineGroupRecord get(
        @Param("id") Long id
    );

    /**
     * 根据ID列表获取分组
     *
     * @param projectId 项目ID
     * @param ids 分组ID集合
     * @return 分组记录列表
     */
    List<TPipelineGroupRecord> listByIds(
        @Param("projectId") String projectId,
        @Param("ids") Set<Long> ids
    );

    /**
     * 获取项目下的指定分组
     *
     * @param projectId 项目ID
     * @param groupId 分组ID
     * @return 分组记录
     */
    TPipelineGroupRecord get(
        @Param("projectId") String projectId,
        @Param("groupId") Long groupId
    );
} 