/*
 * Tencent is pleased to support the open source community by making BK-CI 蓝鲸持续集成平台 available.
 *
 * Copyright (C) 2019 THL A29 Limited, a Tencent company.  All rights reserved.
 *
 * BK-CI 蓝鲸持续集成平台 is licensed under the MIT license.
 *
 * A copy of the MIT License is included in this file.
 *
 *
 * Terms of the MIT License:
 * ---------------------------------------------------
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
 * documentation files (the "Software"), to deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of
 * the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
 * LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package cd.casic.ci.process.process.dal.label;

import cd.casic.ci.process.api.process.pojo.classify.PipelineLabel;

import org.apache.ibatis.annotations.Param;


import java.util.List;

/**
 * 流水线标签 Mapper 接口
 */
public interface PipelineLabelDao {

    /**
     * 创建标签
     *
     * @param projectId 项目ID
     * @param name 标签名称
     * @param desc 标签描述
     * @param userId 用户ID
     * @return 标签ID
     */
    long create(
        @Param("projectId") String projectId,
        @Param("name") String name,
        @Param("desc") String desc,
        @Param("userId") String userId
    );

    /**
     * 更新标签
     *
     * @param projectId 项目ID
     * @param id 标签ID
     * @param name 标签名称
     * @param desc 标签描述
     * @param userId 用户ID
     * @return 影响的行数
     */
    int update(
        @Param("projectId") String projectId,
        @Param("id") long id,
        @Param("name") String name,
        @Param("desc") String desc,
        @Param("userId") String userId
    );

    /**
     * 删除标签
     *
     * @param projectId 项目ID
     * @param id 标签ID
     * @return 影响的行数
     */
    int delete(
        @Param("projectId") String projectId,
        @Param("id") long id
    );

    /**
     * 获取标签列表
     *
     * @param projectId 项目ID
     * @return 标签列表
     */
    List<PipelineLabel> list(
        @Param("projectId") String projectId
    );

    /**
     * 获取标签
     *
     * @param projectId 项目ID
     * @param id 标签ID
     * @return 标签
     */
    PipelineLabel get(
        @Param("projectId") String projectId,
        @Param("id") long id
    );
} 