package cd.casic.ci.process.process.dal.pipeline;


import cd.casic.ci.common.pipeline.enums.BuildStatus;
import cd.casic.ci.common.pipeline.enums.StartType;
import cd.casic.ci.common.pipeline.pojo.BuildParameters;
import cd.casic.ci.common.pipeline.pojo.ErrorInfo;
import cd.casic.ci.process.api.engine.pojo.BuildInfo;
import cd.casic.ci.process.api.engine.pojo.BuildRetryInfo;
import cd.casic.ci.process.api.process.enums.HistorySearchType;
import cd.casic.ci.process.api.process.pojo.BuildStageStatus;
import cd.casic.ci.process.api.process.pojo.app.StartBuildContext;

import java.time.LocalDateTime;
import java.util.Collection;
import java.util.List;
import java.util.Set;

public interface PipelineBuildDao {
    void create( StartBuildContext startBuildContext);

    void updateBuildRetryInfo(
            String projectId,
            String pipelineId,
            String buildId,
            BuildRetryInfo retryInfo
    );

    List<BuildInfo> getBuildTasksByStatus(

            String projectId,
            String pipelineId,
            Set<BuildStatus> statusSet
    );

    int countAllBuildWithStatus(
            String projectId,
            String pipelineId,
            Set<BuildStatus> status
    );
/*
* TODO Record2 是JOOQ包的对象，这个项目使用mybatis，后续具体分析
* */
//    List<Record2<String, String>> getBuildTasksByConcurrencyGroup(
//
//            String projectId,
//            String concurrencyGroup,
//            List<BuildStatus> statusSet
//    );
//
//    List<Record2<String, String>> getBuildTasksByConcurrencyGroupNull(
//
//            String projectId,
//            String pipelineId,
//            List<BuildStatus> statusSet
//    );

    BuildInfo getBuildInfo(

            String projectId,
            String buildId
    );

    BuildInfo getUserBuildInfo(

            String projectId,
            String buildId
    );

    String getStartUser(

            String projectId,
            String buildId
    );

    List<BuildInfo> listBuildInfoByBuildIds(

            Collection<String> buildIds,
            String projectId,
            String startBeginTime,
            String endBeginTime
    );

    List<BuildInfo> listBuildInfoByBuildIdsOnly(

            Collection<String> buildIds
    );

    Collection<BuildInfo> listPipelineBuildInfo(

            String projectId,
            String pipelineId,
            int offset,
            int limit,
            Boolean updateTimeDesc
    );

    Collection<Integer> listPipelineBuildNum(

            String projectId,
            String pipelineId,
            int offset,
            int limit,
            Integer debugVersion
    );

    BuildInfo getBuildInfoByBuildNum(
            String projectId,
            String pipelineId,
            Integer buildNum,
            Set<BuildStatus> statusSet,
            boolean debug
    );

    BuildInfo getOneQueueBuild(
            String projectId,
            String pipelineId
    );

    BuildInfo getOneConcurrencyQueueBuild(

            String projectId,
            String concurrencyGroup,
            String pipelineId
    );

    void startBuild(

            String projectId,
            String buildId,
            LocalDateTime startTime,
            Boolean debug
    );

    void finishBuild(

            String projectId,
            String buildId,
            BuildStatus buildStatus,
            Long executeTime,
            String recommendVersion,
            String remark,
            List<ErrorInfo> errorInfoList,
            Boolean debug
    );

    BuildInfo getLatestBuild(

            String projectId,
            String pipelineId,
            boolean debug
    );

    BuildInfo getLatestFinishedBuild(

            String projectId,
            String pipelineId
    );

    BuildInfo getLatestFailedBuild(

            String projectId,
            String pipelineId
    );

    BuildInfo getLatestSucceedBuild(

            String projectId,
            String pipelineId
    );

    boolean updateStatus(

            String projectId,
            String buildId,
            BuildStatus oldBuildStatus,
            BuildStatus newBuildStatus,
            LocalDateTime startTime,
            List<ErrorInfo> errorInfoList
    );

    void updateExecuteCount(

            String projectId,
            String buildId,
            int executeCount
    );

    int count(

            String projectId,
            String pipelineId,
            List<BuildStatus> status,
            Long startTimeEndTime,
            Integer debugVersion
    );

    int countByStatus(

            String projectId,
            String pipelineId,
            List<BuildStatus> status,
            Long startTimeEndTime,
            Boolean onlyDebug
    );

    int count(

            String projectId,
            String pipelineId,
            List<String> materialAlias,
            String materialUrl,
            List<String> materialBranch,
            String materialCommitId,
            String materialCommitMessage,
            List<BuildStatus> status,
            List<StartType> trigger,
            Long queueTimeStartTime,
            Long queueTimeEndTime,
            Long startTimeStartTime,
            Long startTimeEndTime,
            Long endTimeStartTime,
            Long endTimeEndTime,
            Long totalTimeMin,
            Long totalTimeMax,
            String remark,
            Integer buildNoStart,
            Integer buildNoEnd,
            String buildMsg,
            List<String> startUser,
            Boolean debug,
            List<String> triggerAlias,
            List<String> triggerBranch,
            List<String> triggerUser
    );

    Collection<BuildInfo> listPipelineBuildInfo(

            String projectId,
            String pipelineId,
            List<String> materialAlias,
            String materialUrl,
            List<String> materialBranch,
            String materialCommitId,
            String materialCommitMessage,
            List<BuildStatus> status,
            List<StartType> trigger,
            Long queueTimeStartTime,
            Long queueTimeEndTime,
            Long startTimeStartTime,
            Long startTimeEndTime,
            Long endTimeStartTime,
            Long endTimeEndTime,
            Long totalTimeMin,
            Long totalTimeMax,
            String remark,
            int offset,
            int limit,
            Integer buildNoStart,
            Integer buildNoEnd,
            String buildMsg,
            List<String> startUser,
            Boolean updateTimeDesc,
            Boolean debug,
            List<String> triggerAlias,
            List<String> triggerBranch,
            List<String> triggerUser
    );

    void updateBuildRemark(

            String projectId,
            String pipelineId,
            String buildId,
            String remark
    );

    void updateRecommendVersion(

            String projectId,
            String buildId,
            String recommendVersion
    );

    Collection<BuildInfo> listHistorySearchOptions(

            String projectId,
            String pipelineId,
            Integer debugVersion,
            HistorySearchType type
    );

    BuildInfo getBuildByBuildNum(

            String projectId,
            String pipelineId,
            int buildNum,
            Integer debugVersion
    );

    List<String> getBuilds(

            String projectId,
            String pipelineId,
            Set<BuildStatus> buildStatus,
            Integer debugVersion
    );

    int updateArtifactList(

            String artifactList,
            String projectId,
            String pipelineId,
            String buildId
    );

    void updateBuildMaterial(

            String projectId,
            String buildId,
            String material
    );

    int updateBuildStageStatus(

            String projectId,
            String buildId,
            List<BuildStageStatus> stageStatus,
            BuildStatus oldBuildStatus,
            BuildStatus newBuildStatus,
            List<ErrorInfo> errorInfoList
    );

    String getBuildParameters(

            String projectId,
            String buildId
    );

    boolean updateBuildParameters(

            String projectId,
            String pipelineId,
            String buildId,
            Collection<BuildParameters> buildParameters,
            boolean debug
    );

    int countBuildNumByTime(

            String projectId,
            String pipelineId,
            LocalDateTime startTime,
            LocalDateTime endTime,
            Integer debugVersion
    );

    BuildInfo getBuildInfo(

            String projectId,
            String pipelineId,
            String buildId
    );

    int countBuildNumByVersion(

            String projectId,
            String pipelineId,
            int version
    );

//    List<Record2<Integer, Integer>> batchCountBuildNumByVersion(
//
//            String projectId,
//            String pipelineId,
//            Set<Integer> versions
//    );

    String getDebugResourceStr(

            String projectId,
            String buildId
    );

    List<BuildInfo> getDebugHistory(

            String projectId,
            String pipelineId,
            Integer version
    );

    int clearDebugHistory(

            String projectId,
            String pipelineId,
            Integer version
    );
}