package cd.casic.ci.process.process.dal.pipeline;


import cd.casic.ci.process.api.process.pojo.BuildTemplateAcrossInfo;
import cd.casic.ci.process.process.dataObject.TPipelineBuildTemplateAcrossInfoRecord;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 流水线构建模板跨项目信息Mapper接口
 */
@Repository
public interface PipelineBuildTemplateAcrossInfoDao {

    /**
     * 创建模板跨项目信息
     *
     
     * @param projectId 项目ID
     * @param pipelineId 流水线ID
     * @param buildId 构建ID
     * @param templateId 模板ID
     * @param templateType 模板类型
     * @param templateInstancesIds 模板实例ID列表
     * @param targetProjectId 目标项目ID
     * @param userId 用户ID
     * @return 影响行数
     */
    int create(
        @Param("projectId") String projectId,
        @Param("pipelineId") String pipelineId,
        @Param("buildId") String buildId,
        @Param("templateId") String templateId,
        @Param("templateType") BuildTemplateAcrossInfo.TemplateAcrossInfoType templateType,
        @Param("templateInstancesIds") List<String> templateInstancesIds,
        @Param("targetProjectId") String targetProjectId,
        @Param("userId") String userId
    );

    /**
     * 批量创建模板跨项目信息
     *
     
     * @param projectId 项目ID
     * @param pipelineId 流水线ID
     * @param buildId 构建ID
     * @param userId 用户ID
     * @param templateAcrossInfos 模板跨项目信息列表
     * @return 影响行数
     */
    int batchCreate(
        @Param("projectId") String projectId,
        @Param("pipelineId") String pipelineId,
        @Param("buildId") String buildId,
        @Param("userId") String userId,
        @Param("templateAcrossInfos") List<BuildTemplateAcrossInfo> templateAcrossInfos
    );

    /**
     * 批量更新模板跨项目信息
     *
     
     * @param projectId 项目ID
     * @param pipelineId 流水线ID
     * @param buildId 构建ID
     * @param templateAcrossInfos 模板跨项目信息列表
     * @return 影响行数
     */
    int batchUpdate(
        
        @Param("projectId") String projectId,
        @Param("pipelineId") String pipelineId,
        @Param("buildId") String buildId,
        @Param("templateAcrossInfos") List<BuildTemplateAcrossInfo> templateAcrossInfos
    );

    /**
     * 获取模板跨项目信息
     *
     
     * @param projectId 项目ID
     * @param pipelineId 流水线ID
     * @param templateId 模板ID
     * @return 模板跨项目信息记录列表
     */
    List<TPipelineBuildTemplateAcrossInfoRecord> get(
        
        @Param("projectId") String projectId,
        @Param("pipelineId") String pipelineId,
        @Param("templateId") String templateId
    );

    /**
     * 根据模板ID获取跨项目信息
     *
     
     * @param projectId 项目ID
     * @param templateId 模板ID
     * @return 模板跨项目信息记录列表
     */
    List<TPipelineBuildTemplateAcrossInfoRecord> getByTemplateId(
        
        @Param("projectId") String projectId,
        @Param("templateId") String templateId
    );

    /**
     * 更新构建ID
     *
     
     * @param projectId 项目ID
     * @param pipelineId 流水线ID
     * @param templateId 模板ID
     * @param buildId 构建ID
     * @return 影响行数
     */
    int updateBuildId(
        
        @Param("projectId") String projectId,
        @Param("pipelineId") String pipelineId,
        @Param("templateId") String templateId,
        @Param("buildId") String buildId
    );

    /**
     * 删除模板跨项目信息
     *
     
     * @param projectId 项目ID
     * @param pipelineId 流水线ID
     * @param templateId 模板ID
     * @return 影响行数
     */
    int delete(
        
        @Param("projectId") String projectId,
        @Param("pipelineId") String pipelineId,
        @Param("templateId") String templateId
    );

    /**
     * 根据流水线ID删除跨项目信息
     *
     
     * @param projectId 项目ID
     * @param pipelineId 流水线ID
     * @return 影响行数
     */
    int deleteByPipelineId(
        
        @Param("projectId") String projectId,
        @Param("pipelineId") String pipelineId
    );

    /**
     * 根据构建ID删除跨项目信息
     *
     
     * @param projectId 项目ID
     * @param pipelineId 流水线ID
     * @param buildId 构建ID
     * @return 影响行数
     */
    int deleteByBuildId(
        
        @Param("projectId") String projectId,
        @Param("pipelineId") String pipelineId,
        @Param("buildId") String buildId
    );
} 