/*
 * Tencent is pleased to support the open source community by making BK-CI 蓝鲸持续集成平台 available.
 *
 * Copyright (C) 2019 THL A29 Limited, a Tencent company.  All rights reserved.
 *
 * BK-CI 蓝鲸持续集成平台 is licensed under the MIT license.
 *
 * A copy of the MIT License is included in this file.
 *
 *
 * Terms of the MIT License:
 * ---------------------------------------------------
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
 * documentation files (the "Software"), to deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of
 * the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
 * LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package cd.casic.ci.process.process.dal.pipeline;


import cd.casic.ci.common.pipeline.pojo.BuildParameters;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * 流水线构建变量 Mapper 接口
 */
@Mapper
@Repository
public interface PipelineBuildVarDao {

    /**
     * 创建构建变量
     *
     * @param projectId 项目ID
     * @param pipelineId 流水线ID
     * @param buildId 构建ID
     * @param varName 变量名
     * @param varValue 变量值
     * @return 构建变量ID
     */
    long save(
        @Param("projectId") String projectId,
        @Param("pipelineId") String pipelineId,
        @Param("buildId") String buildId,
        @Param("varName") String varName,
        @Param("varValue") String varValue,
        @Param("readOnly") Boolean readOnly
    );

    /**
     * 更新构建变量
     *
     * @param projectId 项目ID
     * @param pipelineId 流水线ID
     * @param buildId 构建ID
     * @param varType 变量类型
     * @return 影响的行数
     */
    int update(
        @Param("projectId") String projectId,
        @Param("pipelineId") String pipelineId,
        @Param("buildId") String buildId,
        @Param("name") String name,
        @Param("value") String value,
        @Param("varType") String varType,
        @Param("readOnly") Boolean readOnly
    );



    Map<String, String> getVars(
            @Param("projectId") String projectId,
            @Param("buildId") String buildId,
            @Param("keys") Set<String> keys
    );

    List<BuildParameters> getVarsWithType(
            @Param("projectId") String projectId,
            @Param("buildId") String buildId,
            @Param("key") String key
    );

    int deleteBuildVar(
            @Param("projectId") String projectId,
            @Param("buildId") String buildId,
            @Param("varName") String varName,
            @Param("readOnly") Boolean readOnly
    );

    void batchSave(
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId,
            @Param("buildId") String buildId,
            @Param("variables") List<BuildParameters> variables
    );

    void batchUpdate(
            @Param("projectId") String projectId,
            @Param("buildId") String buildId,
            @Param("variables") List<BuildParameters> variables
    );

    void deleteBuildVars(
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId,
            @Param("buildId") String buildId
    );

    void deletePipelineBuildVar(
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId
    );

    Set<String> fetchVarByLikeKey(
            @Param("projectId") String projectId,
            @Param("buildId") String buildId,
            @Param("readOnly") Boolean readOnly,
            @Param("likeStr") String likeStr
    );
} 