/*
 * Tencent is pleased to support the open source community by making BK-CI 蓝鲸持续集成平台 available.
 *
 * Copyright (C) 2019 THL A29 Limited, a Tencent company.  All rights reserved.
 *
 * BK-CI 蓝鲸持续集成平台 is licensed under the MIT license.
 *
 * A copy of the MIT License is included in this file.
 *
 *
 * Terms of the MIT License:
 * ---------------------------------------------------
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
 * documentation files (the "Software"), to deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of
 * the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
 * LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package cd.casic.ci.process.process.dal.pipeline;


import cd.casic.ci.common.pipeline.enums.ChannelCode;
import cd.casic.ci.common.pipeline.enums.VersionStatus;
import cd.casic.ci.process.api.engine.pojo.PipelineInfo;
import cd.casic.ci.process.api.process.pojo.PipelineCollation;
import cd.casic.ci.process.api.process.pojo.PipelineSortType;
import cd.casic.ci.process.process.dataObject.TPipelineInfoRecord;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.time.LocalDateTime;
import java.util.Collection;
import java.util.List;
import java.util.Set;

/**
 * 流水线信息 Mapper 接口
 */
@Mapper
@Repository
public interface PipelineInfoDao {

    int create(
            @Param("pipelineId") String pipelineId,
            @Param("projectId") String projectId,
            @Param("version") int version,
            @Param("pipelineName") String pipelineName,
            @Param("pipelineDesc") String pipelineDesc,
            @Param("userId") String userId,
            @Param("channelCode") ChannelCode channelCode,
            @Param("manualStartup") boolean manualStartup,
            @Param("canElementSkip") boolean canElementSkip,
            @Param("taskCount") int taskCount,
            @Param("id") Long id,
            @Param("latestVersionStatus") VersionStatus latestVersionStatus,
            @Param("pipelineDisable") Boolean pipelineDisable
    );

    boolean update(
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId,
            @Param("userId") String userId,
            @Param("version") Integer version,
            @Param("pipelineName") String pipelineName,
            @Param("pipelineDesc") String pipelineDesc,
            @Param("manualStartup") Boolean manualStartup,
            @Param("canElementSkip") Boolean canElementSkip,
            @Param("taskCount") int taskCount,
            @Param("latestVersion") int latestVersion,
            @Param("updateLastModifyUser") Boolean updateLastModifyUser,
            @Param("latestVersionStatus") VersionStatus latestVersionStatus,
            @Param("locked") Boolean locked
    );

    int countByPipelineIds(
            @Param("projectId") String projectId,
            @Param("channelCode") ChannelCode channelCode,
            @Param("pipelineIds") List<String> pipelineIds
    );

    int countByProjectIds(
            @Param("projectIds") Collection<String> projectIds,
            @Param("channelCode") ChannelCode channelCode,
            @Param("keyword") String keyword
    );

    int countByProjectIds(
            @Param("projectIds") Collection<String> projectIds,
            @Param("channelCodes") List<ChannelCode> channelCodes,
            @Param("keyword") String keyword
    );

    List<String> listPipelineIdByProject(
            @Param("projectId") String projectId
    );

    TPipelineInfoRecord listPipelineInfoByProject(
            
            @Param("projectId") String projectId,
            @Param("limit") int limit,
            @Param("offset") int offset,
            @Param("deleteFlag") Boolean deleteFlag,
            @Param("timeDescFlag") boolean timeDescFlag,
            @Param("channelCode") ChannelCode channelCode
    );

    TPipelineInfoRecord searchByProject(
            
            @Param("pipelineName") String pipelineName,
            @Param("projectCode") String projectCode,
            @Param("limit") int limit,
            @Param("offset") int offset,
            @Param("channelCode") ChannelCode channelCode
    );

    int countPipelineInfoByProject(
            
            @Param("pipelineName") String pipelineName,
            @Param("projectCode") String projectCode,
            @Param("channelCode") ChannelCode channelCode
    );

    TPipelineInfoRecord searchByProject(
            @Param("projectId") String projectId
    );

    TPipelineInfoRecord listPipelinesByProject(
            
            @Param("projectId") String projectId,
            @Param("deleteFlag") Boolean deleteFlag,
            @Param("days") Long days,
            @Param("offset") Integer offset,
            @Param("limit") Integer limit,
            @Param("sortType") PipelineSortType sortType,
            @Param("collation") PipelineCollation collation,
            @Param("filterByPipelineName") String filterByPipelineName
    );

    int countPipeline(
            
            @Param("projectId") String projectId,
            @Param("deleteFlag") Boolean deleteFlag,
            @Param("days") Long days,
            @Param("filterByPipelineName") String filterByPipelineName
    );

    TPipelineInfoRecord listDeletePipelineBefore(
            
            @Param("updateTime") LocalDateTime updateTime,
            @Param("offset") Integer offset,
            @Param("limit") Integer limit
    );

    boolean isNameExist(
            
            @Param("projectId") String projectId,
            @Param("pipelineName") String pipelineName,
            @Param("channelCode") ChannelCode channelCode
    );

    boolean isNameExist(
            
            @Param("projectId") String projectId,
            @Param("pipelineName") String pipelineName,
            @Param("channelCode") ChannelCode channelCode,
            @Param("excludePipelineId") String excludePipelineId
    );

    TPipelineInfoRecord getPipelineInfo(
            
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId,
            @Param("channelCode") ChannelCode channelCode
    );

    TPipelineInfoRecord getPipelineInfo(
            
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId,
            @Param("channelCode") ChannelCode channelCode,
            @Param("delete") Boolean delete,
            @Param("days") Long days
    );

    int softDelete(
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId,
            @Param("changePipelineName") String changePipelineName,
            @Param("userId") String userId,
            @Param("channelCode") ChannelCode channelCode
    );

    int delete(
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId
    );

    TPipelineInfoRecord listInfoByPipelineIds(
            @Param("projectId") String projectId,
            @Param("pipelineIds") Set<String> pipelineIds,
            @Param("filterDelete") boolean filterDelete
    );

    TPipelineInfoRecord getPipelineInfo(
            
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId,
            @Param("version") int version
    );

//    Record1<Int> getPipelineInfoNum(
//
//            @Param("projectIds") Set<String> projectIds,
//            @Param("channelCodes") Set<ChannelCode> channelCodes
//    );

    TPipelineInfoRecord listInfoByPipelineName(
            
            @Param("projectId") String projectId,
            @Param("pipelineNames") Set<String> pipelineNames,
            @Param("filterDelete") boolean filterDelete
    );

    PipelineInfo convert(
            @Param("t") TPipelineInfoRecord t,
            @Param("templateId") String templateId
    );

    void restore(
            
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId,
            @Param("userId") String userId,
            @Param("channelCode") ChannelCode channelCode
    );

    TPipelineInfoRecord searchByProjectId(
            @Param("pipelineName") String pipelineName,
            @Param("projectCode") String projectCode,
            @Param("limit") int limit,
            @Param("offset") int offset,
            @Param("channelCodes") List<ChannelCode> channelCodes
    );

    int getPipelineVersion(
            
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId,
            @Param("userId") String userId,
            @Param("channelCode") ChannelCode channelCode
    );
// TODO
//    Result<Record2<String, Long>> listByProject(
//
//            @Param("projectId") String projectId
//    );

    TPipelineInfoRecord getPipelineId(
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId
    );

    int countExcludePipelineIds(
            @Param("projectId") String projectId,
            @Param("excludePipelineIds") List<String> excludePipelineIds,
            @Param("channelCode") ChannelCode channelCode,
            @Param("includeDelete") boolean includeDelete,
            @Param("filterPipelineIds") List<String> filterPipelineIds
    );

    TPipelineInfoRecord getPipelineByAutoId(
            @Param("ids") List<Long> ids,
            @Param("projectId") String projectId
    );

    void updateLatestStartTime(
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId,
            @Param("startTime") LocalDateTime startTime
    );

    List<String> getIdByCreateTimePeriod(
            @Param("startTime") LocalDateTime startTime,
            @Param("endTime") LocalDateTime endTime,
            @Param("page") int page,
            @Param("pageSize") int pageSize
    );

    TPipelineInfoRecord listByPipelineIds(
            @Param("projectId") String projectId,
            @Param("excludePipelineIds") List<String> excludePipelineIds,
            @Param("channelCode") ChannelCode channelCode,
            @Param("limit") int limit,
            @Param("offset") int offset
    );
} 