/*
 * Tencent is pleased to support the open source community by making BK-CI 蓝鲸持续集成平台 available.
 *
 * Copyright (C) 2019 THL A29 Limited, a Tencent company.  All rights reserved.
 *
 * BK-CI 蓝鲸持续集成平台 is licensed under the MIT license.
 *
 * A copy of the MIT License is included in this file.
 *
 *
 * Terms of the MIT License:
 * ---------------------------------------------------
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
 * documentation files (the "Software"), to deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of
 * the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
 * LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package cd.casic.ci.process.process.dal.pipeline;

import cd.casic.ci.process.api.engine.pojo.PipelineModelTask;
import cd.casic.ci.process.process.dataObject.TPipelineModelTaskRecord;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.time.LocalDateTime;
import java.util.Collection;

/**
 * 流水线模型任务数据访问接口
 */
@Mapper
@Repository
public interface PipelineModelTaskDao {

    void batchSave(
            @Param("modelTasks") Collection<PipelineModelTask> modelTasks
    );

    void deletePipelineTasks(
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId
    );

    int getPipelineCountByAtomCode(
            @Param("atomCode") String atomCode,
            @Param("projectCode") String projectCode
    );

//    Result<Record2<Integer, String>> batchGetPipelineCountByAtomCode(
//            @Param("dslContext") DSLContext dslContext,
//            @Param("atomCodeList") List<String> atomCodeList,
//            @Param("projectCode") String projectCode
//    );
//
//    Result<Record2<String, String>> batchGetPipelineIdByAtomCode(
//            @Param("projectId") String projectId,
//            @Param("atomCodeList") List<String> atomCodeList,
//            @Param("limit") int limit,
//            @Param("offset") int offset
//    );

    TPipelineModelTaskRecord getModelTasks(
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId,
            @Param("isAtomVersionNull") Boolean isAtomVersionNull
    );

    TPipelineModelTaskRecord listByPipelineIds(
            @Param("projectId") String projectId,
            @Param("pipelineIds") Collection<String> pipelineIds
    );

//    Result<Record> listByAtomCode(
//            @Param("atomCode") String atomCode,
//            @Param("projectId") String projectId,
//            @Param("version") String version,
//            @Param("startUpdateTime") LocalDateTime startUpdateTime,
//            @Param("endUpdateTime") LocalDateTime endUpdateTime,
//            @Param("page") Integer page,
//            @Param("pageSize") Integer pageSize
//    );

    long countByAtomCode(
            @Param("atomCode") String atomCode,
            @Param("projectId") String projectId,
            @Param("version") String version,
            @Param("startUpdateTime") LocalDateTime startUpdateTime,
            @Param("endUpdateTime") LocalDateTime endUpdateTime
    );

//    Result<Record> listByAtomCodeAndPipelineIds(
//            @Param("atomCode") String atomCode,
//            @Param("pipelineIds") Set<String> pipelineIds
//    );

    void updateTaskAtomVersion(
            @Param("atomVersion") String atomVersion,
            @Param("createTime") LocalDateTime createTime,
            @Param("updateTime") LocalDateTime updateTime,
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId,
            @Param("stageId") String stageId,
            @Param("containerId") String containerId,
            @Param("taskId") String taskId
    );
} 