package cd.casic.ci.process.process.dal.pipeline;


import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.time.LocalDateTime;
import java.util.List;

/**
 * 最近使用的流水线Mapper接口
 */
@Repository
public interface PipelineRecentUseDao {

    /**
     * 新增记录
     *
     * @param projectId 项目ID
     * @param userId 用户ID
     * @param pipelineId 流水线ID
     * @return 影响的行数
     */
    int add(
        @Param("projectId") String projectId,
        @Param("userId") String userId,
        @Param("pipelineId") String pipelineId
    );

    /**
     * 获取最近使用的流水线ID列表
     *
     
     * @param projectId 项目ID
     * @param userId 用户ID
     * @param limit 限制数量
     * @return 流水线ID列表
     */
    List<String> listRecentPipelineIds(
        @Param("projectId") String projectId,
        @Param("userId") String userId,
        @Param("limit") Integer limit
    );

    /**
     * 获取最近使用时间列表
     *
     
     * @param projectId 项目ID
     * @param userId 用户ID
     * @param limit 限制数量
     * @return 使用时间列表
     */
    List<LocalDateTime> listLastUseTimes(
        
        @Param("projectId") String projectId,
        @Param("userId") String userId,
        @Param("limit") Integer limit
    );

    /**
     * 删除过期记录
     *
     
     * @param projectId 项目ID
     * @param userId 用户ID
     * @param endTime 结束时间
     * @return 影响的行数
     */
    int deleteExpire(
        
        @Param("projectId") String projectId,
        @Param("userId") String userId,
        @Param("endTime") LocalDateTime endTime
    );
} 