/*
 * Tencent is pleased to support the open source community by making BK-CI 蓝鲸持续集成平台 available.
 *
 * Copyright (C) 2019 THL A29 Limited, a Tencent company.  All rights reserved.
 *
 * BK-CI 蓝鲸持续集成平台 is licensed under the MIT license.
 *
 * A copy of the MIT License is included in this file.
 *
 *
 * Terms of the MIT License:
 * ---------------------------------------------------
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
 * documentation files (the "Software"), to deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of
 * the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
 * LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package cd.casic.ci.process.process.dal.pipeline;

import cd.casic.ci.process.api.process.pojo.PipelineStageTag;
import cd.casic.ci.process.process.dataObject.TPipelineStageTagRecord;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 流水线阶段标签Mapper接口
 */
@Repository
public interface PipelineStageTagDao {

    /**
     * 添加阶段标签
     *
     
     * @param id 标签ID
     * @param stageTagName 阶段标签名称
     * @param weight 权重
     * @return 影响的行数
     */
    int add(
        @Param("id") String id,
        @Param("stageTagName") String stageTagName,
        @Param("weight") Integer weight
    );

    /**
     * 删除阶段标签
     *
     
     * @param id 标签ID
     * @return 影响的行数
     */
    int delete(
        @Param("id") String id
    );

    /**
     * 更新阶段标签
     *
     
     * @param id 标签ID
     * @param stageTagName 阶段标签名称
     * @param weight 权重
     * @return 影响的行数
     */
    int update(
        
        @Param("id") String id,
        @Param("stageTagName") String stageTagName,
        @Param("weight") Integer weight
    );

    /**
     * 获取阶段标签
     *
     
     * @param id 标签ID
     * @return 阶段标签记录
     */
    TPipelineStageTagRecord getStageTag(
        
        @Param("id") String id
    );

    /**
     * 获取所有阶段标签
     *
     * @return 所有阶段标签记录
     */
    List<TPipelineStageTagRecord> getAllStageTag();

    /**
     * 获取默认阶段标签
     *
     * @return 默认阶段标签记录
     */
    TPipelineStageTagRecord getDefaultStageTag();

    /**
     * 根据名称或权重统计标签数量
     *
     
     * @param stageTagName 阶段标签名称
     * @param weight 权重
     * @return 标签数量
     */
    Integer countByNameOrWeight(
        @Param("stageTagName") String stageTagName,
        @Param("weight") Integer weight
    );
    static PipelineStageTag convert(TPipelineStageTagRecord record, Boolean defaultFlag){
        return new PipelineStageTag(
                record.getId(),
                record.getStageTagName(),
                record.getWeight(),
                defaultFlag,
                record.getCreateTime().getTime(),
                record.getUpdateTime().getTime()
                );
    }
} 