/*
 * Tencent is pleased to support the open source community by making BK-CI 蓝鲸持续集成平台 available.
 *
 * Copyright (C) 2019 THL A29 Limited, a Tencent company.  All rights reserved.
 *
 * BK-CI 蓝鲸持续集成平台 is licensed under the MIT license.
 *
 * A copy of the MIT License is included in this file.
 *
 *
 * Terms of the MIT License:
 * ---------------------------------------------------
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
 * documentation files (the "Software"), to deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of
 * the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
 * LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package cd.casic.ci.process.process.dal.record;

import cd.casic.ci.common.pipeline.enums.BuildStatus;
import cd.casic.ci.common.pipeline.enums.StartType;
import cd.casic.ci.process.process.dataObject.TPipelineBuildDetailRecord;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.time.LocalDateTime;

/**
 * 构建详情 Mapper 接口
 */
@Mapper
@Repository
public interface BuildDetailDao {

    /**
     * 创建构建详情
     *
     * @param projectId   项目ID
     * @param buildId     构建ID
     * @param startUser   启动用户
     * @param startType   启动类型
     * @param buildNum    构建编号
     * @param model       模型
     * @param buildStatus 构建状态
     */
    void create(
            @Param("projectId") String projectId,
            @Param("buildId") String buildId,
            @Param("startUser") String startUser,
            @Param("startType") StartType startType,
            @Param("buildNum") Integer buildNum,
            @Param("model") String model,
            @Param("buildStatus") BuildStatus buildStatus
    );

    /**
     * 更新构建取消用户
     *
     * @param projectId  项目ID
     * @param buildId    构建ID
     * @param cancelUser 取消用户
     */
    void updateBuildCancelUser(
            @Param("projectId") String projectId,
            @Param("buildId") String buildId,
            @Param("cancelUser") String cancelUser
    );

    /**
     * 更新构建详情
     *
     * @param projectId   项目ID
     * @param buildId     构建ID
     * @param model       模型
     * @param buildStatus 构建状态
     * @param cancelUser  取消用户
     * @return 更新数量
     */
    int update(
            @Param("projectId") String projectId,
            @Param("buildId") String buildId,
            @Param("model") String model,
            @Param("buildStatus") BuildStatus buildStatus,
            @Param("cancelUser") String cancelUser
    );

    /**
     * 更新构建状态
     *
     * @param projectId   项目ID
     * @param buildId     构建ID
     * @param buildStatus 构建状态
     * @param startTime   开始时间
     * @param endTime     结束时间
     */
    void updateStatus(
            @Param("projectId") String projectId,
            @Param("buildId") String buildId,
            @Param("buildStatus") BuildStatus buildStatus,
            @Param("startTime") LocalDateTime startTime,
            @Param("endTime") LocalDateTime endTime
    );

    /**
     * 获取构建详情
     *
     * @param projectId 项目ID
     * @param buildId   构建ID
     * @return 构建详情记录
     */
    TPipelineBuildDetailRecord get(
            @Param("projectId") String projectId,
            @Param("buildId") String buildId
    );
} 