package cd.casic.ci.process.process.dal.record;

import cd.casic.ci.common.pipeline.enums.BuildRecordTimeStamp;
import cd.casic.ci.common.pipeline.enums.BuildStatus;
import cd.casic.ci.common.pipeline.pojo.ErrorInfo;
import cd.casic.ci.common.pipeline.pojo.time.BuildTimestampType;
import cd.casic.ci.process.api.process.pojo.pipeline.BuildRecordInfo;
import cd.casic.ci.process.api.process.pojo.pipeline.record.BuildRecordModel;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

/**
 * 构建记录模型Mapper接口
 */
@Mapper
@Repository
public interface BuildRecordModelDao {
    /**
     * 创建构建记录模型     *     * @param record 记录     * @return 影响行数
     */
    int createBuildRecordModel(@Param("record") BuildRecordModel record);

    /**
     * 更新构建记录模型     *     * @param projectId 项目ID     * @param pipelineId 流水线ID     * @param buildId 构建ID     * @param executeCount 执行次数     * @param buildStatus 构建状�?     * @param modelVar 模型变量     * @param startTime 开始时�?     * @param endTime 结束时间     * @param errorInfoList 错误信息列表     * @param cancelUser 取消用户     * @param timestamps 时间�?     * @return 影响行数
     */
    int updateBuildRecordModel(@Param("projectId") String projectId, @Param("pipelineId") String pipelineId, @Param("buildId") String buildId, @Param("executeCount") int executeCount, @Param("buildStatus") BuildStatus buildStatus, @Param("modelVar") Map<String, Object> modelVar, @Param("startTime") LocalDateTime startTime, @Param("endTime") LocalDateTime endTime, @Param("errorInfoList") List<ErrorInfo> errorInfoList, @Param("cancelUser") String cancelUser, @Param("timestamps") Map<BuildTimestampType, BuildRecordTimeStamp> timestamps);

    /**
     * 更新构建记录模型状�?     *     * @param projectId 项目ID     * @param buildId 构建ID     * @param buildStatus 构建状�?     * @param executeCount 执行次数     * @return 影响行数
     */
    int updateBuildRecordModelStatus(@Param("projectId") String projectId, @Param("buildId") String buildId, @Param("buildStatus") BuildStatus buildStatus, @Param("executeCount") int executeCount);

    /**
     * 获取构建记录模型     *     * @param projectId 项目ID     * @param pipelineId 流水线ID     * @param buildId 构建ID     * @param executeCount 执行次数     * @return 记录
     */
    BuildRecordModel getBuildRecordModel(@Param("projectId") String projectId, @Param("pipelineId") String pipelineId, @Param("buildId") String buildId, @Param("executeCount") int executeCount);

    /**
     * 获取构建记录信息列表     *     * @param projectId 项目ID     * @param pipelineId 流水线ID     * @param buildId 构建ID     * @return 记录信息列表
     */
    List<BuildRecordInfo> getBuildRecordInfoList(@Param("projectId") String projectId, @Param("pipelineId") String pipelineId, @Param("buildId") String buildId);

    /**
     * 更新构建取消用户     *     * @param projectId 项目ID     * @param buildId 构建ID     * @param executeCount 执行次数     * @param cancelUser 取消用户     * @return 影响行数
     */
    int updateBuildCancelUser(@Param("projectId") String projectId, @Param("buildId") String buildId, @Param("executeCount") int executeCount, @Param("cancelUser") String cancelUser);

    /**
     * 获取构建取消用户     *     * @param projectId 项目ID     * @param buildId 构建ID     * @param executeCount 执行次数     * @return 取消用户
     */
    String getBuildCancelUser(@Param("projectId") String projectId, @Param("buildId") String buildId, @Param("executeCount") int executeCount);
}
