package cd.casic.ci.process.process.dal.record;


import cd.casic.ci.common.pipeline.enums.BuildStatus;
import cd.casic.ci.process.api.engine.pojo.PipelineBuildContainer;
import cd.casic.ci.process.api.engine.pojo.PipelineBuildContainerControlOption;
import org.apache.ibatis.annotations.Param;

import java.time.LocalDateTime;
import java.util.Collection;
import java.util.List;
import java.util.Set;

public interface PipelineBuildContainerDao {
    void create(
            @Param("buildContainer") PipelineBuildContainer buildContainer
    );

    void batchSave(
            @Param("containerList") Collection<PipelineBuildContainer> containerList
    );

    void batchUpdate(

            @Param("containerList") List<PipelineBuildContainer> containerList
    );

    PipelineBuildContainer getByContainerId(

            @Param("projectId") String projectId,
            @Param("buildId") String buildId,
            @Param("stageId") String stageId,
            @Param("containerId") String containerId
    );

    int updateStatus(

            @Param("projectId") String projectId,
            @Param("buildId") String buildId,
            @Param("stageId") String stageId,
            @Param("containerId") String containerId,
            @Param("startTime") LocalDateTime startTime,
            @Param("endTime") LocalDateTime endTime,
            @Param("controlOption") PipelineBuildContainerControlOption controlOption,
            @Param("buildStatus") BuildStatus buildStatus
    );

    int updateControlOption(

            @Param("projectId") String projectId,
            @Param("buildId") String buildId,
            @Param("stageId") String stageId,
            @Param("containerId") String containerId,
            @Param("controlOption") PipelineBuildContainerControlOption controlOption
    );

    List<PipelineBuildContainer> listByBuildId(

            @Param("projectId") String projectId,
            @Param("buildId") String buildId,
            @Param("stageId") String stageId,
            @Param("containsMatrix") Boolean containsMatrix,
            @Param("statusSet") Set<BuildStatus> statusSet
    );

    int countStageContainers(

            @Param("projectId") String projectId,
            @Param("buildId") String buildId,
            @Param("stageId") String stageId,
            @Param("onlyMatrixGroup") boolean onlyMatrixGroup
    );

    List<PipelineBuildContainer> listByMatrixGroupId(

            @Param("projectId") String projectId,
            @Param("buildId") String buildId,
            @Param("matrixGroupId") String matrixGroupId
    );

    Collection<String> listBuildContainerIdsInMatrixGroup(

            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId,
            @Param("buildId") String buildId,
            @Param("matrixGroupId") String matrixGroupId,
            @Param("stageId") String stageId
    );

    int deleteBuildContainerInMatrixGroup(

            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId,
            @Param("buildId") String buildId,
            @Param("matrixGroupId") String matrixGroupId
    );
}