package cd.casic.ci.process.process.dal.record;

import cd.casic.ci.common.pipeline.enums.ChannelCode;
import cd.casic.ci.common.pipeline.pojo.BuildNo;
import cd.casic.ci.process.api.process.pojo.PipelineCollation;
import cd.casic.ci.process.api.process.pojo.PipelineSortType;
import cd.casic.ci.process.process.dataObject.TPipelineBuildSummaryRecord;
import cd.casic.ci.process.process.dataObject.TPipelineInfoRecord;
import cd.casic.ci.process.process.pojo.LatestRunningBuild;
import cd.casic.ci.process.process.pojo.PipelineFilterParam;
import org.apache.ibatis.annotations.Param;

import java.util.Collection;
import java.util.List;
import java.util.Set;

public interface PipelineBuildSummaryDao {
    void create(
            
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId,
            @Param("buildNo") BuildNo buildNo
    );

    void delete(
            
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId
    );

    TPipelineBuildSummaryRecord get(
            
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId
    );

    TPipelineBuildSummaryRecord getSummaries(
            
            @Param("projectId") String projectId,
            @Param("pipelineIds") Set<String> pipelineIds
    );

    void resetDebugInfo(
            
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId,
            @Param("debugBuildNo") int debugBuildNo
    );

    void updateBuildNo(
            
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId,
            @Param("buildNo") int buildNo,
            @Param("debug") boolean debug
    );

    Integer getBuildNo(
            
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId,
            @Param("debug") boolean debug
    );

    int updateBuildNum(
            
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId,
            @Param("buildId") String buildId,
            @Param("debug") boolean debug,
            @Param("buildNum") int buildNum,
            @Param("buildNumAlias") String buildNumAlias
    );

    long listPipelineInfoBuildSummaryCount(
            
            @Param("projectId") String projectId,
            @Param("channelCode") ChannelCode channelCode,
            @Param("pipelineIds") Collection<String> pipelineIds,
            @Param("viewId") String viewId,
            @Param("favorPipelines") List<String> favorPipelines,
            @Param("authPipelines") List<String> authPipelines,
            @Param("pipelineFilterParamList") List<PipelineFilterParam> pipelineFilterParamList,
            @Param("permissionFlag") Boolean permissionFlag,
            @Param("includeDelete") Boolean includeDelete,
            @Param("userId") String userId
    );

    TPipelineInfoRecord listPipelineInfoBuildSummary(
            
            @Param("projectId") String projectId,
            @Param("channelCode") ChannelCode channelCode,
            @Param("sortType") PipelineSortType sortType,
            @Param("pipelineIds") Collection<String> pipelineIds,
            @Param("favorPipelines") List<String> favorPipelines,
            @Param("authPipelines") List<String> authPipelines,
            @Param("viewId") String viewId,
            @Param("pipelineFilterParamList") List<PipelineFilterParam> pipelineFilterParamList,
            @Param("permissionFlag") Boolean permissionFlag,
            @Param("page") Integer page,
            @Param("pageSize") Integer pageSize,
            @Param("pageOffsetNum") Integer pageOffsetNum,
            @Param("includeDelete") Boolean includeDelete,
            @Param("collation") PipelineCollation collation,
            @Param("userId") String userId
    );

    void updateQueueCount(
            
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId,
            @Param("queueIncrement") int queueIncrement
    );

    int startLatestRunningBuild(
            
            @Param("latestRunningBuild") LatestRunningBuild latestRunningBuild,
            @Param("executeCount") int executeCount,
            @Param("debug") boolean debug
    );

    void updateCurrentBuildTask(
            
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId,
            @Param("buildId") String buildId,
            @Param("currentTaskId") String currentTaskId,
            @Param("currentTaskName") String currentTaskName
    );

    void finishLatestRunningBuild(
            @Param("latestRunningBuild") LatestRunningBuild latestRunningBuild,
            @Param("isStageFinish") boolean isStageFinish,
            @Param("debug") boolean debug
    );

    void updateRunningCount(
            
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId,
            @Param("buildId") String buildId,
            @Param("runningIncrement") int runningIncrement,
            @Param("debug") boolean debug
    );

    TPipelineBuildSummaryRecord listSummaryByPipelineIds(
            
            @Param("pipelineIds") Collection<String> pipelineIds,
            @Param("projectId") String projectId
    );

    boolean fixPipelineSummaryCount(
            @Param("projectId") String projectId,
            @Param("pipelineId") String pipelineId,
            @Param("finishCount") int finishCount,
            @Param("runningCount") Integer runningCount,
            @Param("queueCount") Integer queueCount
    );
}