/* * Tencent is pleased to support the open source community by making BK-CI 蓝鲸持续集成平台 available. * * Copyright (C) 2019 THL A29 Limited, a Tencent company.  All rights reserved. * * BK-CI 蓝鲸持续集成平台 is licensed under the MIT license. * * A copy of the MIT License is included in this file. * * * Terms of the MIT License: * --------------------------------------------------- * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated * documentation files (the "Software"), to deal in the Software without restriction, including without limitation the * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to * permit persons to whom the Software is furnished to do so, subject to the following conditions: * * The above copyright notice and this permission notice shall be included in all copies or substantial portions of * the Software. * * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT * LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */
package cd.casic.ci.process.process.dal.webhook;

import cd.casic.ci.process.process.pojo.PipelineWebHookQueue;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 流水线WebHook队列 Dao 接口
 */
@Repository
public interface PipelineWebHookQueueDao {
    /**
     * 保存流水线WebHook队列     *          * @param projectId 项目ID     * @param pipelineId 流水线ID     * @param sourceProjectId 源项目ID     * @param sourceRepoName 源仓库名�?     * @param sourceBranch 源分�?     * @param targetProjectId 目标项目ID     * @param targetRepoName 目标仓库名称     * @param targetBranch 目标分支     * @param buildId 构建ID     * @param id ID     * @return 影响的行�?
     */
    int save(@Param("projectId") String projectId, @Param("pipelineId") String pipelineId, @Param("sourceProjectId") Long sourceProjectId, @Param("sourceRepoName") String sourceRepoName, @Param("sourceBranch") String sourceBranch, @Param("targetProjectId") Long targetProjectId, @Param("targetRepoName") String targetRepoName, @Param("targetBranch") String targetBranch, @Param("buildId") String buildId, @Param("id") Long id);

    /**
     * 获取WebHook构建历史     *          * @param projectId 项目ID     * @param pipelineId 流水线ID     * @param sourceProjectId 源项目ID     * @param sourceBranch 源分�?     * @param targetProjectId 目标项目ID     * @param targetBranch 目标分支     * @return WebHook队列列表
     */
    List<PipelineWebHookQueue> getWebHookBuildHistory(@Param("projectId") String projectId, @Param("pipelineId") String pipelineId, @Param("sourceProjectId") Long sourceProjectId, @Param("sourceBranch") String sourceBranch, @Param("targetProjectId") Long targetProjectId, @Param("targetBranch") String targetBranch);

    /**
     * 获取WebHook队列     *          * @param projectId 项目ID     * @param buildId 构建ID     * @return WebHook队列
     */
    PipelineWebHookQueue get(@Param("projectId") String projectId, @Param("buildId") String buildId);

    /**
     * 根据构建ID删除WebHook队列     *          * @param projectId 项目ID     * @param buildIds 构建ID列表     * @return 影响的行�?
     */
    int deleteByBuildIds(@Param("projectId") String projectId, @Param("buildIds") List<String> buildIds);
}
