package cd.casic.ci.process.process.engine.listener;

import cd.casic.ci.common.pipeline.service.utils.LogUtils;
import cd.casic.ci.process.process.engine.control.CallBackControl;
import cd.casic.ci.process.process.engine.pojo.event.PipelineCreateEvent;
import cd.casic.ci.process.process.engine.service.AgentPipelineRefService;
import cd.casic.ci.process.process.engine.service.PipelineAtomStatisticsService;
import cd.casic.ci.process.process.engine.service.PipelineWebhookService;
import cd.casic.ci.process.process.engine.service.RepoPipelineRefService;
import cd.casic.framework.commons.util.watcher.Watcher;
import cd.casic.framework.mq.redis.core.stream.AbstractRedisStreamMessageListener;
import com.github.fppt.jedismock.operations.transactions.Watch;
import org.springframework.stereotype.Service;
/**
 *  MQ实现的流水线创建事件
 *
 * @version 1.0
 */
@Service
public class MQPipelineCreateListener extends AbstractRedisStreamMessageListener<PipelineCreateEvent> {
    private PipelineWebhookService pipelineWebhookService;
    private PipelineAtomStatisticsService pipelineAtomStatisticsService;
    private CallBackControl callBackControl;
    private AgentPipelineRefService agentPipelineRefService;
    private RepoPipelineRefService repoPipelineRefService;
    @Override
    public void onMessage(PipelineCreateEvent event) {
        String id = String.format("%s|CreatePipeline#%s|%s",
                event.getTraceId(),event.getPipelineId(),event.getUserId()
        );
        Watcher watcher = new Watcher(id);

        watcher.safeAround("callback",()-> {
            callBackControl.pipelineCreateEvent(event.getProjectId(), event.getPipelineId());
        });

        watcher.safeAround("updateAtomPipelineNum",()->{
            pipelineAtomStatisticsService.updateAtomPipelineNum(
                    event.getProjectId(),
                    event.getPipelineId(),
                    event.getVersion()!=null ?event.getVersion(): 1,
                    false,
                    false
            );
        });

        watcher.safeAround("updateAgentPipelineRef",()->{
            agentPipelineRefService.updateAgentPipelineRef(event.getUserId(), "create_pipeline", event.getProjectId(), event.getPipelineId());
        });

        watcher.safeAround("addWebhook",()-> {
            pipelineWebhookService.addWebhook(
                    event.getProjectId(),
                    event.getPipelineId(),
                    event.getVersion(),
                    event.getUserId()
            );
        });

        watcher.safeAround("savePipelineRefRepository",()->{
            repoPipelineRefService.updateRepoPipelineRef(event.getUserId(), "create_pipeline", event.getProjectId(), event.getPipelineId());
        }) ;

        LogUtils.printCostTimeWE(watcher);
    }
}
