package cd.casic.ci.process.process.engine.listener;

import cd.casic.ci.common.pipeline.service.utils.LogUtils;
import cd.casic.ci.process.process.engine.control.CallBackControl;
import cd.casic.ci.process.process.engine.pojo.event.PipelineCreateEvent;
import cd.casic.ci.process.process.engine.pojo.event.PipelineDeleteEvent;
import cd.casic.ci.process.process.engine.service.*;
import cd.casic.framework.commons.util.watcher.Watcher;
import cd.casic.framework.mq.redis.core.stream.AbstractRedisStreamMessageListener;
import jakarta.annotation.Resource;
import org.springframework.stereotype.Service;
/**
 *  MQ实现的流水线删除事件
 *
 * @version 1.0
 */
@Service
public class MQPipelineDeleteListener extends AbstractRedisStreamMessageListener<PipelineDeleteEvent> {
    @Resource
    private PipelineRuntimeService pipelineRuntimeService;
    @Resource
    private PipelineWebhookService pipelineWebhookService;
    @Resource
    private PipelineGroupService pipelineGroupService;
    @Resource
    private PipelineAtomStatisticsService pipelineAtomStatisticsService;
    @Resource
    private CallBackControl callBackControl;
    @Resource
    private AgentPipelineRefService agentPipelineRefService;
    @Resource
    private RepoPipelineRefService repoPipelineRefService;
    @Override
    public void onMessage(PipelineDeleteEvent event) {
        String id = String.format("%s|DeletePipeline#%s|%s}",
                event.getTraceId(),
                event.getPipelineId(),
                event.isClearUpModel());
        Watcher watcher = new  Watcher(id);
        final String projectId = event.getProjectId();
        final String pipelineId = event.getPipelineId();
        final String userId = event.getUserId();

        watcher.safeAround("cancelPendingTask",()->{
            pipelineRuntimeService.cancelPendingTask(projectId, pipelineId, userId);
        });

        if (event.isClearUpModel()) {
            watcher.safeAround("deleteExt",()-> {
                pipelineGroupService.deleteAllUserFavorByPipeline(userId, projectId, pipelineId); // 删除收藏该流水线上所有记录
                pipelineGroupService.deletePipelineLabel(userId, projectId, pipelineId);
            });
        }

        watcher.safeAround("deleteWebhook",()->{
            pipelineWebhookService.deleteWebhook(projectId, pipelineId, userId);
        });

        watcher.safeAround("updateAgentPipelineRef",()->{
            agentPipelineRefService.updateAgentPipelineRef(userId, "delete_pipeline", projectId, pipelineId);
        });

        watcher.safeAround("updateAtomPipelineNum",()->{
            pipelineAtomStatisticsService.updateAtomPipelineNum(
                    event.getProjectId(),
                    event.getPipelineId(),
                    null,
                    true,
                    false
            );
        });

        watcher.safeAround("updateAgentPipelineRef",()->{
            repoPipelineRefService.updateRepoPipelineRef(userId, "delete_pipeline", projectId, pipelineId);
        });

        watcher.safeAround("callback",
                ()->{
                    callBackControl.pipelineDeleteEvent(event.getProjectId(), event.getPipelineId());
                });

        LogUtils.printCostTimeWE(watcher);
    }
}
