package cd.casic.ci.process.process.engine.listener;

import cd.casic.ci.common.pipeline.service.utils.LogUtils;
import cd.casic.ci.process.process.engine.control.CallBackControl;
import cd.casic.ci.process.process.engine.pojo.event.PipelineDeleteEvent;
import cd.casic.ci.process.process.engine.pojo.event.PipelineRestoreEvent;
import cd.casic.ci.process.process.engine.service.AgentPipelineRefService;
import cd.casic.ci.process.process.engine.service.PipelineAtomStatisticsService;
import cd.casic.ci.process.process.engine.service.RepoPipelineRefService;
import cd.casic.framework.commons.util.watcher.Watcher;
import cd.casic.framework.mq.redis.core.stream.AbstractRedisStreamMessageListener;
import jakarta.annotation.Resource;
import org.springframework.stereotype.Service;

/**
 *  MQ实现的流水线恢复事件
 *
 * @version 1.0
 */
@Service
public class MQPipelineRestoreListener  extends AbstractRedisStreamMessageListener<PipelineRestoreEvent> {
    @Resource
    private AgentPipelineRefService agentPipelineRefService;
    @Resource
    private PipelineAtomStatisticsService pipelineAtomStatisticsService;
    @Resource
    private CallBackControl callBackControl;
    @Resource
    private RepoPipelineRefService repoPipelineRefService;

    @Override
    public void onMessage(PipelineRestoreEvent event) {
        String id = String.format("%s|RestorePipeline#%s|%s}",
                event.getTraceId(),
                event.getPipelineId(),
                event.getUserId()
                ) ;
        Watcher watcher = new Watcher(id);
        try {
            watcher.start("updateAgentPipelineRef");
            String userId = event.getUserId();
            String projectId = event.getProjectId();
            String pipelineId = event.getPipelineId();
            Integer version = event.getVersion();
            agentPipelineRefService.updateAgentPipelineRef(userId, "restore_pipeline", projectId, pipelineId);

            watcher.stop();
            watcher.start("updateAtomPipelineNum");
            pipelineAtomStatisticsService.updateAtomPipelineNum(
                    projectId,
                    pipelineId,
                    version,
                    false,
                    true
            );
            watcher.stop();
            watcher.start("callback");
            callBackControl.pipelineRestoreEvent(projectId, pipelineId);
            repoPipelineRefService.updateRepoPipelineRef(userId, "restore_pipeline", projectId, pipelineId);

        } finally {
            watcher.stop();
            LogUtils.printCostTimeWE(watcher);
        }
    }
}
