package cd.casic.ci.process.process.engine.listener;

import cd.casic.ci.common.pipeline.service.utils.LogUtils;
import cd.casic.ci.process.process.engine.control.CallBackControl;
import cd.casic.ci.process.process.engine.pojo.event.PipelineUpdateEvent;
import cd.casic.ci.process.process.engine.service.AgentPipelineRefService;
import cd.casic.ci.process.process.engine.service.PipelineAtomStatisticsService;
import cd.casic.ci.process.process.engine.service.PipelineWebhookService;
import cd.casic.ci.process.process.engine.service.RepoPipelineRefService;
import cd.casic.framework.commons.util.watcher.Watcher;
import cd.casic.framework.mq.redis.core.stream.AbstractRedisStreamMessageListener;
import org.springframework.stereotype.Service;

/**
 *  MQ实现的流水线更新事件
 *
 * @version 1.0
 */
@Service
public class MQPipelineUpdateListener extends AbstractRedisStreamMessageListener<PipelineUpdateEvent> {
    private PipelineAtomStatisticsService pipelineAtomStatisticsService;
    private CallBackControl callBackControl;
    private AgentPipelineRefService agentPipelineRefService;
    private PipelineWebhookService pipelineWebhookService;
    private RepoPipelineRefService repoPipelineRefService;

    @Override
    public void onMessage(PipelineUpdateEvent event) {
        String id = String.format("%s|RestorePipeline#%s|%s}",
                event.getTraceId(),
                event.getPipelineId(),
                event.getUserId()
        ) ;
        Watcher watcher = new  Watcher(id);
        final String projectId = event.getProjectId();
        final String pipelineId = event.getPipelineId();
        final String userId = event.getUserId();
        final Integer version = event.getVersion();

        watcher.safeAround("callback",()->{
            callBackControl.pipelineUpdateEvent(projectId, pipelineId);
        });

        watcher.safeAround("updateAgentPipelineRef",()->{
            agentPipelineRefService.updateAgentPipelineRef(userId, "update_pipeline", projectId, pipelineId);
        });

        watcher.safeAround("updateAtomPipelineNum",()->{
            pipelineAtomStatisticsService.updateAtomPipelineNum(projectId,pipelineId, version,false,false);
        });

        watcher.safeAround("addWebhook",()->{
            pipelineWebhookService.addWebhook(
                    projectId ,
                    pipelineId ,
                    version ,
                    userId
            );
        });

        watcher.safeAround("updateAgentPipelineRef",()->{

          repoPipelineRefService.updateRepoPipelineRef(userId, "update_pipeline", projectId, pipelineId);

        });

        LogUtils.printCostTimeWE(watcher);
    }
}
