package cd.casic.ci.process.process.engine.service;

import cd.casic.ci.process.api.process.pojo.classify.*;
import cd.casic.ci.process.process.dataObject.TPipelineFavorRecord;

import java.util.Collection;
import java.util.List;
import java.util.Map;

/**
 * 流水线分组服务接口
 */
public interface PipelineGroupService {

    /**
     * 获取分组列表
     */
    List<PipelineGroup> getGroups(String userId, String projectId);

    /**
     * 获取指定流水线的分组列表
     */
    List<PipelineGroupWithLabels> getGroups(String userId, String projectId, String pipelineId);

    /**
     * 添加分组
     */
    Boolean addGroup(String userId, PipelineGroupCreate pipelineGroup);

    /**
     * 更新分组
     */
    Boolean updateGroup(String userId, PipelineGroupUpdate pipelineGroup);

    /**
     * 删除分组
     */
    Boolean deleteGroup(String userId, String projectId, String groupId);

    /**
     * 添加标签
     */
    Boolean addLabel(String userId, String projectId, PipelineLabelCreate pipelineLabel);

    /**
     * 删除标签
     */
    Boolean deleteLabel(String userId, String projectId, String labelId);

    /**
     * 更新标签
     */
    Boolean updateLabel(String userId, String projectId, PipelineLabelUpdate pipelineLabel);

    /**
     * 删除流水线标签
     */
    void deletePipelineLabel(String userId, String projectId, String pipelineId);

    /**
     * 添加流水线标签
     */
    void addPipelineLabel(String userId, String projectId, String pipelineId, List<String> labelIds);

    /**
     * 更新流水线标签
     */
    void updatePipelineLabel(String userId, String projectId, String pipelineId, List<String> labelIds);

    /**
     * 获取视图标签到流水线的映射
     */
    Map<String, List<String>> getViewLabelToPipelinesMap(
            String projectId,
            List<String> labels
    );

    /**
     * 获取分组到标签的映射
     */
    Map<String, List<String>> getGroupToLabelsMap(String projectId, List<String> labels);

    /**
     * 收藏流水线
     */
    Boolean favorPipeline(String userId, String projectId, String pipelineId, Boolean favor);

    /**
     * 删除流水线相关的所有收藏
     */
    Integer deleteAllUserFavorByPipeline(String userId, String projectId, String pipelineId);

    /**
     * 获取收藏的流水线列表
     */
    List<String> getFavorPipelines(String userId, String projectId);

    /**
     * 获取流水线分组标签
     */
    Map<String, List<PipelineGroupLabels>> getPipelinesGroupLabel(
            Collection<String> pipelineIds,
            String projectId
    );

    /**
     * 分页获取收藏的流水线
     */
    TPipelineFavorRecord getFavorPipelinesPage(
            String userId,
            Integer page,
            Integer pageSize
    );
}
