package cd.casic.ci.process.process.engine.service;


import cd.casic.ci.common.pipeline.Model;
import cd.casic.ci.common.pipeline.enums.RepositoryConfig;
import cd.casic.ci.common.pipeline.enums.ScmType;
import cd.casic.ci.common.pipeline.pojo.element.trigger.enums.CodeEventType;
import cd.casic.ci.log.scm.dal.pojo.Repository;
import cd.casic.ci.process.api.process.pojo.webhook.PipelineWebhook;
import cd.casic.ci.process.api.process.pojo.webhook.WebhookTriggerPipeline;

import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * 流水线Webhook服务接口
 */
public interface PipelineWebhookService {

    /**
     * 添加Webhook
     */
    void addWebhook(
            String projectId,
            String pipelineId,
            Integer version,
            String userId
    );

    /**
     * 注册Webhook
     */
    Repository registerWebhook(
            String projectId,
            ScmType scmType,
            RepositoryConfig repositoryConfig,
            CodeEventType codeEventType,
            String elementVersion
    );

    /**
     * 删除Webhook
     */
    Boolean deleteWebhook(
            String projectId,
            String pipelineId,
            String userId
    );

    /**
     * 删除指定任务的Webhook
     */
    Boolean deleteWebhook(
            String projectId,
            String pipelineId,
            String taskId,
            String userId
    );

    /**
     * 获取模型
     */
    Model getModel(
            String projectId,
            String pipelineId,
            Integer version
    );

    /**
     * 获取触发流水线列表
     */
    List<WebhookTriggerPipeline> getTriggerPipelines(
            String name,
            ScmType repositoryType,
            List<String> yamlPipelineIds
    );

    /**
     * 列出触发流水线
     */
    List<WebhookTriggerPipeline> listTriggerPipeline(
            String projectId,
            String repositoryHashId,
            String eventType
    );

    /**
     * 获取项目名称
     */
    String getProjectName(String projectName);

    /**
     * 获取外部名称
     */
    String getExternalName(ScmType scmType, String projectName);

    /**
     * 列出Webhook
     */
    List<PipelineWebhook> listWebhook(
            String userId,
            String projectId,
            String pipelineId,
            Integer page,
            Integer pageSize
    );

    /**
     * 获取Webhook
     */
    PipelineWebhook get(
            String projectId,
            String pipelineId,
            String repositoryHashId,
            String eventType
    );
}
