package cd.casic.ci.process.process.engine.service;



import cd.casic.ci.common.pipeline.Model;
import cd.casic.ci.common.pipeline.enums.RepositoryConfig;
import cd.casic.ci.common.pipeline.pojo.element.Element;

import java.util.Map;

/**
 * 流水线代码库使用服务接口
 * @version 1.0
 */
public interface RepoPipelineRefService {

    /**
     * 更新代码库流水线引用
     *
     * @param userId 用户ID
     * @param action 操作类型
     * @param projectId 项目ID
     * @param pipelineId 流水线ID
     */
    void updateRepoPipelineRef(String userId, String action, String projectId, String pipelineId);

    /**
     * 更新流水线引用
     *
     * @param userId 用户ID
     * @param projectId 项目ID
     * @param pipelineId 流水线ID
     */
    void updatePipelineRef(String userId, String projectId, String pipelineId);

    /**
     * 更新所有流水线引用
     *
     * @param projectId 项目ID，可为空
     */
    void updateAllPipelineRef(String projectId);

    /**
     * 分析流水线引用并保存
     *
     * @param userId 用户ID
     * @param action 操作类型
     * @param projectId 项目ID
     * @param pipelineId 流水线ID
     * @param model 流水线模型
     * @param channel 渠道
     */
    void analysisPipelineRefAndSave(
            String userId,
            String action,
            String projectId,
            String pipelineId,
            Model model,
            String channel
    );

    /**
     * 获取任务参数
     *
     * @param element 元素
     * @return 任务参数Map
     */
    Map<String, Object> getTaskParams(Element element);

    /**
     * 获取市场构建代码库配置
     *
     * @param input 输入参数
     * @param variables 变量Map
     * @return 代码库配置
     */
    RepositoryConfig getMarketBuildRepoConfig(Map<?, ?> input, Map<String, String> variables);
}
