package cd.casic.ci.process.process.service.audit.impl;

import cd.casic.ci.common.pipeline.constant.CommonConstants;
import cd.casic.ci.common.pipeline.model.SQLPage;
import cd.casic.ci.process.api.process.pojo.audit.Audit;
import cd.casic.ci.process.api.process.pojo.audit.AuditInfo;
import cd.casic.ci.process.api.process.pojo.audit.QueryAudit;
import cd.casic.ci.process.process.constant.AllocIdGenerateConstant;
import cd.casic.ci.process.process.dal.audit.AuditDao;
import cd.casic.ci.process.process.dataObject.TAuditResourceRecord;
import cd.casic.ci.process.process.service.audit.AuditService;
import cd.casic.ci.project.service.ServiceAllocIdResource;
import jakarta.annotation.Resource;
import org.apache.commons.lang3.tuple.ImmutablePair;
import org.apache.commons.lang3.tuple.Pair;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class AuditServiceImpl implements AuditService {
    @Resource
    private AuditDao auditDao;
    @Resource
    private ServiceAllocIdResource serviceAllocIdResource;

    @Override
    public Long createAudit(Audit audit) {
        Long id = serviceAllocIdResource.generateSegmentId(AllocIdGenerateConstant.AUDIT_RESOURCE);
        return auditDao.create(
                audit.getResourceType(),
                audit.getResourceId(),
                audit.getResourceName(),
                audit.getUserId(),
                audit.getAction(),
                audit.getActionContent(),
                audit.getProjectId(),
                id
        );
    }

    @Override
    public Pair<SQLPage<AuditInfo>, Boolean> userList(QueryAudit queryAudit, Integer offset, Integer limit) {
        Long count = auditDao.countByResourceTye(queryAudit);
        List<TAuditResourceRecord> auditRecordList = auditDao.listByResourceTye(queryAudit, offset, limit);
        List<AuditInfo> auditList = auditRecordList.stream().map(it -> {
            String statusStr = "1".equals(it.getStatus()) ? CommonConstants.SUCCESS : CommonConstants.FAIL;
            return new AuditInfo(
                    it.getStatus(),
                    it.getResourceType(),
                    it.getResourceId(),
                    it.getResourceName(),
                    it.getUserId(),
                    it.getCreatedTime().getTime(),
                    it.getAction(),
                    it.getActionContent()
            );
        }).toList();

        return new ImmutablePair<>(new SQLPage<>(count,auditList),true);
    }
}
