package cd.casic.ci.process.process.service.base.engin.service;

import cd.casic.ci.common.pipeline.Model;
import cd.casic.ci.common.pipeline.dialect.IPipelineDialect;
import cd.casic.ci.common.pipeline.enums.BranchVersionAction;
import cd.casic.ci.common.pipeline.enums.ChannelCode;
import cd.casic.ci.common.pipeline.enums.VersionStatus;
import cd.casic.ci.common.pipeline.pojo.setting.PipelineSetting;
import cd.casic.ci.common.pipeline.pojo.transfer.YamlWithVersion;
import cd.casic.ci.process.api.engine.pojo.PipelineInfo;
import cd.casic.ci.process.api.engine.pojo.PipelineModelTask;
import cd.casic.ci.process.api.process.pojo.PipelineCollation;
import cd.casic.ci.process.api.process.pojo.PipelineName;
import cd.casic.ci.process.api.process.pojo.PipelineSortType;
import cd.casic.ci.process.api.process.pojo.pipeline.DeletePipelineResult;
import cd.casic.ci.process.api.process.pojo.pipeline.DeployPipelineResult;
import cd.casic.ci.process.api.process.pojo.pipeline.PipelineResourceVersion;
import cd.casic.ci.process.api.process.pojo.pipeline.PipelineYamlVo;
import cd.casic.ci.process.api.process.pojo.setting.PipelineModelVersion;
import org.apache.commons.lang3.tuple.Triple;
import org.springframework.stereotype.Repository;

import java.util.Collection;
import java.util.List;
import java.util.Map;
import java.util.Set;

@Repository
public interface PipelineRepositoryService {

    DeployPipelineResult deployPipeline(
            Model model,
            String projectId,
            String signPipelineId,
            String userId,
            ChannelCode channelCode,
            boolean create,
            YamlWithVersion yaml,
            Integer baseVersion,
            Boolean useSubscriptionSettings,
            Boolean useConcurrencyGroup,
            String templateId,
            Boolean updateLastModifyUser,
            PipelineSetting setting,
            VersionStatus versionStatus,
            String branchName,
            String description,
            PipelineYamlVo yamlInfo,
            Boolean pipelineDisable
    );

    List<PipelineModelTask> initModel(
            Model model,
            String projectId,
            String pipelineId,
            String userId,
            boolean create,
            VersionStatus versionStatus,
            ChannelCode channelCode,
            PipelineYamlVo yamlInfo,
            IPipelineDialect pipelineDialect
    );

    PipelineSetting createDefaultSetting(
            String projectId,
            String pipelineId,
            String pipelineName,
            ChannelCode channelCode
    );

    PipelineInfo getPipelineInfo(
            String projectId,
            String pipelineId,
            ChannelCode channelCode,
            Boolean delete
    );

    Map<String, Model> listModel(String projectId, Collection<String> pipelineIds);

    Triple<PipelineInfo, PipelineResourceVersion, Boolean> getBuildTriggerInfo(
            String projectId,
            String pipelineId,
            Integer version
    );

    PipelineResourceVersion getPipelineResourceVersion(
            String projectId,
            String pipelineId,
            Integer version,
            Boolean includeDraft
    );

    PipelineResourceVersion getDraftVersionResource(
            String projectId,
            String pipelineId
    );

    PipelineResourceVersion getBranchVersionResource(
            String projectId,
            String pipelineId,
            String branchName
    );

    int getActiveBranchVersionCount(
            String projectId,
            String pipelineId
    );

    PipelineResourceVersion rollbackDraftFromVersion(
            String userId,
            String projectId,
            String pipelineId,
            PipelineResourceVersion targetVersion,
            Boolean ignoreBase
    );

    DeletePipelineResult deletePipeline(
            String projectId,
            String pipelineId,
            String userId,
            ChannelCode channelCode,
            boolean delete
    );

    boolean isPipelineExist(
            String projectId,
            String pipelineName,
            ChannelCode channelCode,
            String excludePipelineId
    );

    int countByProjectIds(Set<String> projectIds, ChannelCode channelCode);

    Map<String, String> listPipelineNameByIds(
            String projectId,
            Set<String> pipelineIds,
            boolean filterDelete
    );

    Map<String, String> listPipelineIdByName(
            String projectId,
            Set<String> pipelineNames,
            boolean filterDelete
    );

    Integer getBuildNo(String projectId, String pipelineId);

    PipelineSetting getSetting(String projectId, String pipelineId);

    PipelineSetting getSettingByPipelineVersion(
            String projectId,
            String pipelineId,
            Integer pipelineVersion
    );

    PipelineName saveSetting(
            String userId,
            PipelineSetting setting,
            int version,
            VersionStatus versionStatus,
            Boolean updateLastModifyUser,
            boolean isTemplate
    );

    void batchUpdatePipelineModel(
            String userId,
            List<PipelineModelVersion> pipelineModelVersionList
    );

    List<PipelineInfo> listDeletePipelineIdByProject(
            String projectId,
            Long days,
            Integer offset,
            Integer limit,
            PipelineSortType sortType,
            PipelineCollation collation,
            String filterByPipelineName
    );

    PipelineResourceVersion restorePipeline(
            String projectId,
            String pipelineId,
            String userId,
            ChannelCode channelCode,
            Long days
    );

    int countByPipelineIds(
            String projectId,
            ChannelCode channelCode,
            List<String> pipelineIds
    );

    void updateModelName(
            String pipelineId,
            String projectId,
            String modelName,
            String userId
    );

    int updateMaxConRunningQueueSize(
            String userId,
            String projectId,
            String pipelineId,
            int maxConRunningQueueSize
    );

    DeployPipelineResult updateSettingVersion(
            String userId,
            String projectId,
            String pipelineId,
            PipelineSetting savedSetting,
            Boolean updateLastModifyUser
    );

    void updatePipelineBranchVersion(
            String userId,
            String projectId,
            String pipelineId,
            String branchName,
            BranchVersionAction branchVersionAction
    );

    boolean updateLocked(
            String userId,
            String projectId,
            String pipelineId,
            boolean locked
    );

    String getPipelineOauthUser(String projectId, String pipelineId);
}
