package cd.casic.ci.process.process.service.base.pojo;


import cd.casic.ci.common.pipeline.enums.CallBackEvent;
import cd.casic.ci.event.enums.ActionType;

import java.util.Map;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * 事件工具类
 */
public class EventUtils {

    private static final Map<String, CallBackEvent> callBackEventMap = Stream.of(CallBackEvent.values())
            .collect(Collectors.toMap(Enum::name, event -> event));

    private EventUtils() {
        // 私有构造函数，防止实例化
    }

    /**
     * 将PipelineBuildStatusBroadCastEvent转换为CallBackEvent
     * @param event 构建状态广播事件
     * @return 回调事件类型
     */
    public static CallBackEvent toEventType(PipelineBuildStatusBroadCastEvent event) {
        if (event.getType() != null && callBackEventMap.containsKey(event.getType().name())) {
            return callBackEventMap.get(event.getType().name());
        }

        if (event.getTaskId() != null && !event.getTaskId().isBlank()) {
            if (event.getActionType() == ActionType.START) {
                return CallBackEvent.BUILD_TASK_START;
            }
            if (event.getActionType() == ActionType.REFRESH) {
                return CallBackEvent.BUILD_TASK_PAUSE;
            }
            if (event.getActionType() == ActionType.END) {
                return CallBackEvent.BUILD_TASK_END;
            }
        }

        if (event.getContainerHashId() != null && !event.getContainerHashId().isBlank()) {
            if (event.getActionType() == ActionType.START) {
                return CallBackEvent.BUILD_JOB_START;
            }
            if (event.getActionType() == ActionType.END) {
                return CallBackEvent.BUILD_JOB_END;
            }
        }

        if (event.getStageId() != null && !event.getStageId().isBlank()) {
            if (event.getActionType() == ActionType.START) {
                return CallBackEvent.BUILD_STAGE_START;
            }
            if (event.getActionType() == ActionType.END) {
                return CallBackEvent.BUILD_STAGE_END;
            }
        }

        if ((event.getTaskId() == null || event.getTaskId().isBlank()) &&
                (event.getContainerHashId() == null || event.getContainerHashId().isBlank()) &&
                (event.getStageId() == null || event.getStageId().isBlank())) {
            if (event.getActionType() == ActionType.START) {
                return CallBackEvent.BUILD_START;
            }
            if (event.getActionType() == ActionType.END) {
                return CallBackEvent.BUILD_END;
            }
        }

        return null;
    }
}