package cd.casic.ci.process.process.service.base.pojo;



import cd.casic.ci.event.enums.ActionType;
import cd.casic.ci.event.enums.PipelineBuildStatusBroadCastEventType;

import cd.casic.ci.event.pojo.pipeline.IPipelineEvent;
import org.jetbrains.annotations.Nullable;

import java.time.LocalDateTime;
import java.util.Map;
import java.util.Objects;

/**
 * 构建状态的广播事件，用于通知等
 */
//@Event(destination = StreamBinding.PIPELINE_BUILD_CALL_BACK_FANOUT)
public class PipelineBuildStatusBroadCastEvent extends IPipelineEvent {
    private final String buildId;
    @Nullable
    private final String stageId;
    @Nullable
    private final String containerHashId;
    @Nullable
    private final String jobId;
    @Nullable
    private final String taskId;
    @Nullable
    private final String stepId;
    @Nullable
    private final Integer executeCount;
    @Nullable
    private final String buildStatus;
    @Nullable
    private final String atomCode;
    @Nullable
    private final LocalDateTime eventTime;
    @Nullable
    private final PipelineBuildStatusBroadCastEventType type;
    @Nullable
    private final Map<String, String> labels;

    public PipelineBuildStatusBroadCastEvent(
            String source,
            String projectId,
            String pipelineId,
            String userId,
            String buildId,
            @Nullable String stageId,
            @Nullable String containerHashId,
            @Nullable String jobId,
            @Nullable String taskId,
            @Nullable String stepId,
            @Nullable Integer executeCount,
            @Nullable String buildStatus,
            @Nullable String atomCode,
            @Nullable LocalDateTime eventTime,
            @Nullable PipelineBuildStatusBroadCastEventType type,
            @Nullable Map<String, String> labels,
            ActionType actionType,
            int delayMills
    ) {
        super(actionType, source, projectId, pipelineId, userId, delayMills);
        this.buildId = buildId;
        this.stageId = stageId;
        this.containerHashId = containerHashId;
        this.jobId = jobId;
        this.taskId = taskId;
        this.stepId = stepId;
        this.executeCount = executeCount;
        this.buildStatus = buildStatus;
        this.atomCode = atomCode;
        this.eventTime = eventTime;
        this.type = type;
        this.labels = labels;
    }

    public PipelineBuildStatusBroadCastEvent(
            String source,
            String projectId,
            String pipelineId,
            String userId,
            String buildId,
            @Nullable Integer executeCount,
            @Nullable String buildStatus,
            ActionType actionType
    ) {
        this(
                source,
                projectId,
                pipelineId,
                userId,
                buildId,
                null,
                null,
                null,
                null,
                null,
                executeCount,
                buildStatus,
                null,
                LocalDateTime.now(),
                null,
                null,
                actionType,
                0
        );
    }

    public String getBuildId() {
        return buildId;
    }

    @Nullable
    public String getStageId() {
        return stageId;
    }

    @Nullable
    public String getContainerHashId() {
        return containerHashId;
    }

    @Nullable
    public String getJobId() {
        return jobId;
    }

    @Nullable
    public String getTaskId() {
        return taskId;
    }

    @Nullable
    public String getStepId() {
        return stepId;
    }

    @Nullable
    public Integer getExecuteCount() {
        return executeCount;
    }

    @Nullable
    public String getBuildStatus() {
        return buildStatus;
    }

    @Nullable
    public String getAtomCode() {
        return atomCode;
    }

    @Nullable
    public LocalDateTime getEventTime() {
        return eventTime;
    }

    @Nullable
    public PipelineBuildStatusBroadCastEventType getType() {
        return type;
    }

    @Nullable
    public Map<String, String> getLabels() {
        return labels;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        PipelineBuildStatusBroadCastEvent that = (PipelineBuildStatusBroadCastEvent) o;
        return Objects.equals(buildId, that.buildId) &&
                Objects.equals(stageId, that.stageId) &&
                Objects.equals(containerHashId, that.containerHashId) &&
                Objects.equals(jobId, that.jobId) &&
                Objects.equals(taskId, that.taskId) &&
                Objects.equals(stepId, that.stepId) &&
                Objects.equals(executeCount, that.executeCount) &&
                Objects.equals(buildStatus, that.buildStatus) &&
                Objects.equals(atomCode, that.atomCode) &&
                Objects.equals(eventTime, that.eventTime) &&
                type == that.type &&
                Objects.equals(labels, that.labels);
    }

    @Override
    public int hashCode() {
        return Objects.hash(super.hashCode(), buildId, stageId, containerHashId, jobId, taskId, stepId,
                executeCount, buildStatus, atomCode, eventTime, type, labels);
    }

    @Override
    public String toString() {
        return "PipelineBuildStatusBroadCastEvent{" +
                "buildId='" + buildId + '\'' +
                ", stageId='" + stageId + '\'' +
                ", containerHashId='" + containerHashId + '\'' +
                ", jobId='" + jobId + '\'' +
                ", taskId='" + taskId + '\'' +
                ", stepId='" + stepId + '\'' +
                ", executeCount=" + executeCount +
                ", buildStatus='" + buildStatus + '\'' +
                ", atomCode='" + atomCode + '\'' +
                ", eventTime=" + eventTime +
                ", type=" + type +
                ", labels=" + labels +
                '}';
    }
}
