package cd.casic.ci.process.process.service.base.pojo;


import cd.casic.ci.event.enums.ActionType;
import cd.casic.ci.event.pojo.pipeline.IPipelineEvent;

//@Event(StreamBinding.PIPELINE_BUILD_WEBSOCKET)
public class PipelineBuildWebSocketPushEvent extends IPipelineEvent {

    private final String buildId;
    private final long refreshTypes; // HISTORY or DETAIL or STATUS 位运算
    private final Integer executeCount;

    public PipelineBuildWebSocketPushEvent(
            String source,
            String projectId,
            String pipelineId,
            String userId,
            String buildId,
            long refreshTypes,
            Integer executeCount,
            ActionType actionType,
            int delayMills
    ) {
        super(actionType, source, projectId, pipelineId, userId, delayMills);
        this.buildId = buildId;
        this.refreshTypes = refreshTypes;
        this.executeCount = executeCount;
    }

    public PipelineBuildWebSocketPushEvent(
            String source,
            String projectId,
            String pipelineId,
            String userId,
            String buildId,
            long refreshTypes
    ) {
        this(source, projectId, pipelineId, userId, buildId, refreshTypes, null, ActionType.REFRESH, 0);
    }

    public PipelineBuildWebSocketPushEvent( String source, String projectId, String pipelineId, String userId, String buildId, long refreshTypes, Integer executeCount) {
        super(ActionType.REFRESH, source, projectId, pipelineId, userId,0);
        this.buildId = buildId;
        this.refreshTypes = refreshTypes;
        this.executeCount = executeCount;
    }

    public String getBuildId() {
        return buildId;
    }

    public long getRefreshTypes() {
        return refreshTypes;
    }

    public Integer getExecuteCount() {
        return executeCount;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;

        PipelineBuildWebSocketPushEvent that = (PipelineBuildWebSocketPushEvent) o;

        if (refreshTypes != that.refreshTypes) return false;
        if (!buildId.equals(that.buildId)) return false;
        return executeCount != null ? executeCount.equals(that.executeCount) : that.executeCount == null;
    }

    @Override
    public int hashCode() {
        int result = super.hashCode();
        result = 31 * result + buildId.hashCode();
        result = 31 * result + (int) (refreshTypes ^ (refreshTypes >>> 32));
        result = 31 * result + (executeCount != null ? executeCount.hashCode() : 0);
        return result;
    }

    @Override
    public String toString() {
        return "PipelineBuildWebSocketPushEvent{" +
                "source='" + getSource() + '\'' +
                ", projectId='" + getProjectId() + '\'' +
                ", pipelineId='" + getPipelineId() + '\'' +
                ", userId='" + getUserId() + '\'' +
                ", buildId='" + buildId + '\'' +
                ", refreshTypes=" + refreshTypes +
                ", executeCount=" + executeCount +
                ", actionType=" + getActionType() +
                ", delayMills=" + getDelayMills() +
                '}';
    }
}
