package cd.casic.ci.process.process.service.base.pojo;


import cd.casic.ci.common.pipeline.container.Container;
import cd.casic.ci.common.pipeline.pojo.element.ElementAdditionalOptions;
import cd.casic.ci.common.pipeline.pojo.element.ElementPostInfo;
import cd.casic.ci.process.api.engine.pojo.PipelineBuildTask;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 生成运行环境操作的插件任务
 */
@Repository
public interface VmOperateTaskGenerator {

    String START_VM_TASK_ATOM = "dispatchVMStartupTaskAtom";
    String SHUTDOWN_VM_TASK_ATOM = "dispatchVMShutdownTaskAtom";
    String START_NORMAL_TASK_ATOM = "dispatchBuildLessDockerStartupTaskAtom";
    String SHUTDOWN_NORMAL_TASK_ATOM = "dispatchBuildLessDockerShutdownTaskAtom";

    static boolean isVmAtom(PipelineBuildTask task) {
        return isStartVM(task) || isStopVM(task);
    }

    static boolean isVmAtom(String atomCode) {
        return isStartVM(atomCode) || isStopVM(atomCode);
    }

    static boolean isStartVM(PipelineBuildTask task) {
        return START_VM_TASK_ATOM.equals(task.getTaskAtom()) ||
                START_NORMAL_TASK_ATOM.equals(task.getTaskAtom());
    }

    static boolean isStopVM(PipelineBuildTask task) {
        return SHUTDOWN_VM_TASK_ATOM.equals(task.getTaskAtom()) ||
                SHUTDOWN_NORMAL_TASK_ATOM.equals(task.getTaskAtom());
    }

    static boolean isStartVM(String atomCode) {
        return atomCode.startsWith(START_VM_TASK_ATOM) ||
                atomCode.startsWith(START_NORMAL_TASK_ATOM);
    }

    static boolean isStopVM(String atomCode) {
        return atomCode.startsWith(SHUTDOWN_VM_TASK_ATOM) ||
                atomCode.startsWith(SHUTDOWN_NORMAL_TASK_ATOM);
    }

    /**
     * 生成编译环境的开机插件任务
     */
    PipelineBuildTask makeStartVMContainerTask(
            String projectId,
            String pipelineId,
            String buildId,
            String stageId,
            Container container,
            int taskSeq,
            String userId,
            int executeCount
    );

    /**
     * 生成准备停机插件任务列表
     */
    List<PipelineBuildTask> makeShutdownVMContainerTasks(
            String projectId,
            String pipelineId,
            String buildId,
            String stageId,
            Container container,
            int containerSeq,
            int taskSeq,
            String userId,
            int executeCount
    );

    default ElementAdditionalOptions opts(Container container, String taskName, int taskSeq) {
        return new ElementAdditionalOptions(
                true, // continueWhenFailed
                1L, // timeout: 1分钟超时
                ElementAdditionalOptions.RunCondition.PARENT_TASK_FINISH,
                new ElementPostInfo(
                        container.getId(),
                        "",
                        "",
                        taskName,
                        taskSeq
                )
        );
    }
}
