package cd.casic.pipeline.store.api.common;

import cd.casic.framework.commons.pojo.CommonResult;
import cd.casic.framework.commons.pojo.PageResult;
import cd.casic.pipeline.store.pojo.common.approval.StoreApproveDetail;
import cd.casic.pipeline.store.pojo.common.approval.StoreApproveInfo;
import cd.casic.pipeline.store.pojo.common.approval.StoreApproveRequest;
import cd.casic.pipeline.store.pojo.common.enums.ApproveStatusEnum;
import cd.casic.pipeline.store.pojo.common.enums.ApproveTypeEnum;
import cd.casic.pipeline.store.pojo.common.enums.StoreTypeEnum;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.web.bind.annotation.*;

import static cd.casic.ci.common.pipeline.constant.OpsHeader.AUTH_HEADER_USER_ID;

@Tag(name = "USER_MARKET_APPROVAL", description = "store组件审批")
@RestController
@RequestMapping("/user/market/approval/")
public interface UserStoreApproveResource {

    @Operation(summary = "工作台-审批组件")
    @PutMapping("/types/{storeType}/codes/{storeCode}/ids/{approveId}/approve")
    CommonResult<Boolean> approveStoreInfo(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "组件类型", required = true)
            @PathVariable("storeType")
            StoreTypeEnum storeType,
            @Parameter(description = "组件标识", required = true)
            @PathVariable("storeCode")
            String storeCode,
            @Parameter(description = "审批ID", required = true)
            @PathVariable("approveId")
            String approveId,
            @Parameter(description = "store审批信息请求报文体", required = true)
            StoreApproveRequest storeApproveRequest
    );

    @Operation(summary = "工作台-获取组件审批信息列表")
    @GetMapping("/types/{storeType}/codes/{storeCode}/list")
    PageResult<StoreApproveInfo> getStoreApproveInfos(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "组件类型", required = true)
            @PathVariable("storeType")
            StoreTypeEnum storeType,
            @Parameter(description = "组件标识", required = true)
            @PathVariable("storeCode")
            String storeCode,
            @Parameter(description = "申请人", required = false)
            @RequestParam("applicant")
            String applicant,
            @Parameter(description = "审批类型", required = false)
            @RequestParam("approveType")
            ApproveTypeEnum approveType,
            @Parameter(description = "审批状态", required = false)
            @RequestParam("approveStatus")
            ApproveStatusEnum approveStatus,
            @Parameter(description = "页码", required = true)
            @RequestParam("page")
            Integer page,
            @Parameter(description = "每页数量", required = true)
            @RequestParam("pageSize")
            Integer pageSize
    );

    @Operation(summary = "获取组件审批信息详情")
    @GetMapping("/ids/{approveId}")
    CommonResult<StoreApproveDetail> getStoreApproveDetail(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "审批ID", required = true)
            @PathVariable("approveId")
            String approveId
    );

    @Operation(summary = "获取用户关于组件的审批信息")
    @GetMapping("/types/{storeType}/codes/{storeCode}/user")
    CommonResult<StoreApproveInfo> getUserStoreApproveInfo(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "组件类型", required = true)
            @PathVariable("storeType")
            StoreTypeEnum storeType,
            @Parameter(description = "组件标识", required = true)
            @PathVariable("storeCode")
            String storeCode,
            @Parameter(description = "审批类型", required = true)
            @RequestParam("approveType")
            ApproveTypeEnum approveType
    );
}