package cd.casic.pipeline.store.api.common;


import cd.casic.framework.commons.pojo.CommonResult;
import cd.casic.pipeline.store.pojo.common.InstallStoreReq;
import cd.casic.pipeline.store.pojo.common.StoreBaseInfoUpdateRequest;
import cd.casic.pipeline.store.pojo.common.UnInstallReq;
import cd.casic.pipeline.store.pojo.common.enums.StoreTypeEnum;
import cd.casic.pipeline.store.pojo.common.test.StoreTestRequest;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.web.bind.annotation.*;

import static cd.casic.ci.common.pipeline.constant.OpsHeader.*;


@Tag(name = "USER_STORE_COMPONENT", description = "研发商店-组件管理")
@RestController
@RequestMapping("/user/store/components")
public interface UserStoreComponentManageResource {

    @Operation(summary = "更新组件基本信息")
    @PutMapping("/types/{storeType}/codes/{storeCode}/component/base/info/update")
    CommonResult<Boolean> updateComponentBaseInfo(
            @Parameter(description = "用户ID", required = true, example = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "组件类型", required = true)
            @PathVariable("storeType")
            String storeType,
            @Parameter(description = "组件代码", required = true)
            @PathVariable("storeCode")
            String storeCode,
            @Parameter(description = "组件基本信息修改请求报文体", required = true)
            StoreBaseInfoUpdateRequest storeBaseInfoUpdateRequest
    );

    @Operation(summary = "安装组件到项目")
    @PostMapping("/component/install")
    CommonResult<Boolean> installComponent(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "安装组件到项目请求报文体", required = true)
            InstallStoreReq installStoreReq
    );

    @Operation(summary = "卸载组件")
    @DeleteMapping("/projects/{projectCode}/types/{storeType}/codes/{storeCode}/component/uninstall")
    CommonResult<Boolean> uninstallComponent(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "项目代码", required = true)
            @PathVariable("projectCode")
            String projectCode,
            @Parameter(description = "组件类型", required = true)
            @PathVariable("storeType")
            String storeType,
            @Parameter(description = "组件代码", required = true)
            @PathVariable("storeCode")
            String storeCode,
            @Parameter(description = "卸载组件请求包体", required = true)
            UnInstallReq unInstallReq
    );

    @Operation(summary = "删除工作台组件")
    @DeleteMapping("/desk/types/{storeType}/codes/{storeCode}/component/delete")
    CommonResult<Boolean> deleteComponent(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "组件类型", required = true)
            @PathVariable("storeType")
            String storeType,
            @Parameter(description = "组件代码", required = true)
            @PathVariable("storeCode")
            String storeCode
    );

    @Operation(summary = "更改组件授权人信息")
    @PutMapping("/types/{storeType}/codes/{storeCode}/component/repository/authorizer/update")
    CommonResult<Boolean> updateStoreRepositoryAuthorizer(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "组件类型", required = true)
            @PathVariable("storeType")
            StoreTypeEnum storeType,
            @Parameter(description = "组件代码", required = true)
            @PathVariable("storeCode")
            String storeCode
    );

    @Operation(summary = "保存组件测试信息")
    @PutMapping("/types/{storeType}/codes/{storeCode}/component/test/info/save")
    CommonResult<Boolean> saveStoreTestInfo(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "组件类型", required = true)
            @PathVariable("storeType")
            StoreTypeEnum storeType,
            @Parameter(description = "组件代码", required = true)
            @PathVariable("storeCode")
            String storeCode,
            @Parameter(description = "组件测试信息请求报文", required = true)
            StoreTestRequest storeTestRequest
    );
}