package cd.casic.ci.ticket.service;


import cd.casic.framework.commons.exception.ServiceException;
import cd.casic.framework.commons.util.encrypt.DHKeyPair;
import cd.casic.framework.commons.util.encrypt.DHUtil;
import cd.casic.ci.ticket.dal.dao.CredentialRecordMapper;
import cd.casic.ci.ticket.dal.dataobject.CredentialRecord;
import cd.casic.ci.ticket.dal.pojo.Credential;
import cd.casic.ci.ticket.dal.pojo.CredentialInfo;
import cd.casic.ci.ticket.dal.enums.CredentialType;
import jakarta.annotation.Resource;
import org.springframework.stereotype.Service;

import java.util.Base64;


@Service
public class CredentialServiceImpl implements CredentialService {

    @Resource
    private CredentialHelper credentialHelper;
    @Resource
    private CredentialRecordMapper credentialRecordMapper;

    @Override
    public Credential serviceGet(String projectId, String credentialId) {
        CredentialRecord record = credentialRecordMapper.selectOne(CredentialRecord::getProjectId, projectId, CredentialRecord::getCredentialId, credentialId);
        if (record == null) {
            throw new ServiceException(-1000, "credentialId:" + credentialId + "does not exist");
        }
        return Credential.builder()
                .credentialId(record.getCredentialId())
                .credentialName(record.getCredentialName())
                .credentialType(CredentialType.valueOf(record.getCredentialType()))
                .credentialRemark(record.getCredentialRemark())
                .v1(credentialHelper.decryptCredential(record.getCredentialV1()))
                .v2(credentialHelper.decryptCredential(record.getCredentialV2()))
                .v3(credentialHelper.decryptCredential(record.getCredentialV3()))
                .v4(credentialHelper.decryptCredential(record.getCredentialV4()))
                .updateUser("这里从租户获取到用户id，占位")
                .build();
    }

    @Override
    public CredentialInfo serviceGet(String projectId, String credentialId, String publicKey) {
        CredentialRecord record = credentialRecordMapper.selectOne(CredentialRecord::getProjectId, projectId, CredentialRecord::getCredentialId, credentialId);
        if (record == null) {
            throw new ServiceException(-1000, "credentialId:" + credentialId + "does not exist");
        }
        return credentialInfo(publicKey, record);
    }

    private CredentialInfo credentialInfo(String publicKey, CredentialRecord credentialRecord) {
        byte[] publicKeyByteArray = Base64.getDecoder().decode(publicKey);
        DHKeyPair severDHKeyPair = DHUtil.initKey(publicKeyByteArray);
        assert severDHKeyPair != null;
        byte[] serverPublicKeyByteArray = severDHKeyPair.getPublicKey();
        byte[] serverPrivateKeyByteArray = severDHKeyPair.getPrivateKey();
        String serverBase64PublicKey = new String(Base64.getEncoder().encode(serverPublicKeyByteArray));

        String credentialV1 = credentialHelper.encryptCredential(credentialRecord.getCredentialV1(), publicKeyByteArray, serverPrivateKeyByteArray);
        assert credentialV1 != null;
        String credentialV2 = credentialHelper.encryptCredential(credentialRecord.getCredentialV2(), publicKeyByteArray, serverPrivateKeyByteArray);
        String credentialV3 = credentialHelper.encryptCredential(credentialRecord.getCredentialV3(), publicKeyByteArray, serverPrivateKeyByteArray);
        String credentialV4 = credentialHelper.encryptCredential(credentialRecord.getCredentialV4(), publicKeyByteArray, serverPrivateKeyByteArray);

        return new CredentialInfo(serverBase64PublicKey,
                CredentialType.valueOf(credentialRecord.getCredentialType()),
                credentialV1, credentialV2, credentialV3, credentialV4,
                credentialRecord.getAllowAcrossProject());
    }

}
